************************************************************************************************

*** Do partnership transitions affect the individual perception of aging in later life? Findings from the German Ageing Survey and the NRW80+ study
*** Journal of Family Research, 2023
*** Title: 01_JFR_Preparation_DEAS
*** Author: Luisa Bischoff

*** Data set: DEAS
* 1996: SUF_DEAS1996_3-0_de_Stata, doi: 10.5156/DEAS.1996.M.004
* 2002: SUF_DEAS2002_3-1_de_Stata, doi: 10.5156/DEAS.2002.M.005
* 2008: SUF_DEAS2008_3-1_de_Stata, doi: 10.5156/DEAS.2008.M.005
* 2011: SUF_DEAS_2011_2-1_de_Stata, doi: 10.5156/DEAS.2011.M.004
* 2014: SUF_DEAS_2014_3-0_de, doi: 10.5156/DEAS.2014.M.005
* 2017: SUF_DEAS_2017_2-0_de, doi: 10.5156/DEAS.2017.M.003
* Meta: SUF_DEAS_Meta_05_2020_de

************************************************************************************************
************************************************************************************************

clear all
capture log close
version 16.1
set more off

*Directories
global inpath 	//	directory of original data
global outpath 	//  working directory
cd $inpath	

************************************************************************************************
*** Sampling

use SUF_DEAS1996_3-0_de_Stata.dta, clear

keep if v5_11==1  
// Keep respondents who are retired

drop if v9_29==1  
// Exclude the never-married

save SUF_DEAS1996_3-0_de_Stata_JFR.dta, replace

************************************************************************************************
use SUF_DEAS2002_3-1_de_Stata.dta, clear

keep if w14_11==1  
// Keep respondents who are retired

drop if w18_11==5  
// Exclude the never-married

save SUF_DEAS2002_3-1_de_Stata_JFR.dta, replace

************************************************************************************************
use SUF_DEAS2008_3-1_de_Stata.dta, clear

keep if x100==1  
// Keep respondents who are retired

drop if x200==5  
// Exclude the never-married

save SUF_DEAS2008_3-1_de_Stata_JFR.dta, replace

************************************************************************************************
use SUF_DEAS_2011_2-1_de_Stata.dta, clear

keep if gc100==1  
// Keep respondents who are retired

drop if gc200==5  
// Exclude the never-married

save SUF_DEAS_2011_2-1_de_Stata_JFR.dta, replace

************************************************************************************************
use SUF_DEAS_2014_3-0_de.dta, clear

keep if hc100==1  
// Keep respondents who are retired

rename hc200 marital5
replace marital5 = 5 if famstand_14==5
drop if marital5 == 5 
rename marital5 hc200
// Exclude the never-married

save SUF_DEAS_2014_3-0_de_JFR.dta, replace

************************************************************************************************
use SUF_DEAS_2017_2-0_de.dta, clear

keep if ic100==1  
// Keep respondents who are retired

drop if famstand_17==5  
// Exclude the never-married

save SUF_DEAS_2017_2-0_de_JFR.dta, replace

************************************************************************************************
*** Merging the waves 

* Opening wave 1
use SUF_DEAS1996_3-0_de_Stata_JFR.dta, clear

* Adding wave 2
merge 1:1 fallnum using SUF_DEAS2002_3-1_de_Stata_JFR.dta

* Adding wave 3
drop _merge
merge 1:1 fallnum using SUF_DEAS2008_3-1_de_Stata_JFR.dta

* Adding wave 4
drop _merge
merge 1:1 fallnum using SUF_DEAS_2011_2-1_de_Stata_JFR.dta

* Adding wave 5
drop _merge
merge 1:1 fallnum using SUF_DEAS_2014_3-0_de_JFR.dta

* Adding wave 6
drop _merge
merge 1:1 fallnum using SUF_DEAS_2017_2-0_de_JFR.dta

* Adding the meta data set
drop _merge
merge 1:1 fallnum using SUF_DEAS_Meta_05_2020_de.dta

* Sampling  
drop if _merge==2 
/// Deleting the respondents who did not merge

drop if n_obs==1  
/// Deleting respondent who participated only once


************************************************************************************************
************************************************************************************************
*** Preparation of the relevant variables

************************************************************************************************
* Dependent variables
rename d4_20 freedom1
rename d4_13 needs1
rename d4_19 adaption1
rename d1_30 cognitive1
rename d4_40 dependency1
rename d4_46 vitality1
rename d4_48 serenity1

rename e1_1 freedom2
rename e1_11 needs2
rename e14_4 adaption2
rename e14_6 cognitive2
rename e14_10 dependency2
rename e14_14 vitality2
rename e14_15 serenity2

rename f1_1 freedom3
rename f1_6 needs3
rename f16_3 adaption3
rename f16_5 cognitive3
rename f16_7 dependency3
rename f16_9 vitality3
rename f16_10 serenity3

rename gd1_1 freedom4
rename gd1_6 needs4
rename gd13_3 adaption4
rename gd13_5 cognitive4
rename gd13_7 dependency4
rename gd13_9 vitality4
rename gd13_10 serenity4

rename hd1_1 freedom5
rename hd1_6 needs5
rename hd17_3 adaption5
rename hd17_5 cognitive5
rename hd17_7 dependency5
rename hd17_9 vitality5
rename hd17_10 serenity5

rename id1_1 freedom6
rename id1_6 needs6
rename id14_3 adaption6
rename id14_5 cognitive6
rename id14_7 dependency6
rename id14_9 vitality6
rename id14_10 serenity6


* Recoding negatively formulated perceptions
recode adaption1 adaption2 adaption3 adaption4 adaption5 adaption6 dependency1 dependency2 dependency3 dependency4 dependency5 dependency6 vitality1 vitality2 vitality3 vitality4 vitality5 vitality6 (1=0) (2=1) (3=2) (4=3)

label define PERCEPTIONNEG 0 "Strongly agree" 1 "Agree" 2 "Disagree" 3 "Strongly disagree" 

foreach X of varlist adaption1 adaption2 adaption3 adaption4 adaption5 adaption6 dependency1 dependency2 dependency3 dependency4 dependency5 dependency6 vitality1 vitality2 vitality3 vitality4 vitality5 vitality6 {
	label values `X' PERCEPTIONNEG
}

foreach X of varlist adaption1 adaption2 adaption3 adaption4 adaption5 adaption6 {
	label variable `X' "Perception of ageing: Adaption"
}

foreach X of varlist dependency1 dependency2 dependency3 dependency4 dependency5 dependency6 {
	label variable `X' "Perception of ageing: Dependency"
}

foreach X of varlist vitality1 vitality2 vitality3 vitality4 vitality5 vitality6 {
	label variable `X' "Perception of ageing: Vitality"
}

* Recoding positively formulated perceptions
recode freedom1 freedom2 freedom3 freedom4 freedom5 freedom6 needs1 needs2 needs3 needs4 needs5 needs6 cognitive1 cognitive2 cognitive3 cognitive4 cognitive5 cognitive6 serenity1 serenity2 serenity3 serenity4 serenity5 serenity6 (4=0) (3=1) (2=2) (1=3) 

label define PERCEPTIONPOS 0 "Strongly disagree" 1 "Disagree" 2 "Agree" 3 "Strongly agree" 

foreach X of varlist freedom1 freedom2 freedom3 freedom4 freedom5 freedom6 needs1 needs2 needs3 needs4 needs5 needs6 cognitive1 cognitive2 cognitive3 cognitive4 cognitive5 cognitive6 serenity1 serenity2 serenity3 serenity4 serenity5 serenity6 {
	label values `X' PERCEPTIONPOS
}

foreach X of varlist freedom1 freedom2 freedom3 freedom4 freedom5 freedom6 {
	label variable `X' "Perception of ageing: Freedom"
}

foreach X of varlist needs1 needs2 needs3 needs4 needs5 needs6  {
	label variable `X' "Perception of ageing: Needs"
}

foreach X of varlist cognitive1 cognitive2 cognitive3 cognitive4 cognitive5 cognitive6 {
	label variable `X' "Perception of ageing: Cognitive capacity"
}

foreach X of varlist serenity1 serenity2 serenity3 serenity4 serenity5 serenity6 {
	label variable `X' "Perception of ageing: Serenity"
}


* Generating the index for PA
egen pa1 = rowmean(freedom1 needs1 adaption1 serenity1 cognitive1 dependency1 vitality1)
egen pa2 = rowmean(freedom2 needs2 adaption2 serenity2 cognitive2 dependency2 vitality2)
egen pa3 = rowmean(freedom3 needs3 adaption3 serenity3 cognitive3 dependency3 vitality3)
egen pa4 = rowmean(freedom4 needs4 adaption4 serenity4 cognitive4 dependency4 vitality4)
egen pa5 = rowmean(freedom5 needs5 adaption5 serenity5 cognitive5 dependency5 vitality5)
egen pa6 = rowmean(freedom6 needs6 adaption6 serenity5 cognitive6 dependency6 vitality6)

foreach X of varlist pa1-pa6 {
	label variable `X' "Perceptions of ageing (index)"
}

replace freedom2 = freedom1 if (freedom1 != .c) & (freedom2 == .c)
replace freedom3 = freedom2 if (freedom2 != .c) & (freedom3 == .c)
replace freedom4 = freedom3 if (freedom3 != .c) & (freedom4 == .c)
replace freedom5 = freedom4 if (freedom4 != .c) & (freedom5 == .c)
replace freedom6 = freedom5 if (freedom5 != .c) & (freedom6 == .c)
replace freedom3 = .c if (part_08==0) & (part_11==0) & (part_14==0) & (part_17==0)
replace freedom4 = .c if (part_11==0) & (part_14==0) & (part_17==0)
replace freedom5 = .c if (part_14==0) & (part_17==0)
replace freedom6 = .c if (part_17==0)

replace needs2 = needs1 if (needs1 != .c) & (needs2 == .c)
replace needs3 = needs2 if (needs2 != .c) & (needs3 == .c)
replace needs4 = needs3 if (needs3 != .c) & (needs4 == .c)
replace needs5 = needs4 if (needs4 != .c) & (needs5 == .c)
replace needs6 = needs5 if (needs5 != .c) & (needs6 == .c)
replace needs3 = .c if (part_08==0) & (part_11==0) & (part_14==0) & (part_17==0)
replace needs4 = .c if (part_11==0) & (part_14==0) & (part_17==0)
replace needs5 = .c if (part_14==0) & (part_17==0)
replace needs6 = .c if (part_17==0)

replace adaption2 = adaption1 if (adaption1 != .c) & (adaption2 == .c)
replace adaption3 = adaption2 if (adaption2 != .c) & (adaption3 == .c)
replace adaption4 = adaption3 if (adaption3 != .c) & (adaption4 == .c)
replace adaption5 = adaption4 if (adaption4 != .c) & (adaption5 == .c)
replace adaption6 = adaption5 if (adaption5 != .c) & (adaption6 == .c)
replace adaption3 = .c if (part_08==0) & (part_11==0) & (part_14==0) & (part_17==0)
replace adaption4 = .c if (part_11==0) & (part_14==0) & (part_17==0)
replace adaption5 = .c if (part_14==0) & (part_17==0)
replace adaption6 = .c if (part_17==0)

replace serenity2 = serenity1 if (serenity1 != .c) & (serenity2 == .c)
replace serenity3 = serenity2 if (serenity2 != .c) & (serenity3 == .c)
replace serenity4 = serenity3 if (serenity3 != .c) & (serenity4 == .c)
replace serenity5 = serenity4 if (serenity4 != .c) & (serenity5 == .c)
replace serenity6 = serenity5 if (serenity5 != .c) & (serenity6 == .c)
replace serenity3 = .c if (part_08==0) & (part_11==0) & (part_14==0) & (part_17==0)
replace serenity4 = .c if (part_11==0) & (part_14==0) & (part_17==0)
replace serenity5 = .c if (part_14==0) & (part_17==0)
replace serenity6 = .c if (part_17==0)

replace cognitive2 = cognitive1 if (cognitive1 != .c) & (cognitive2 == .c)
replace cognitive3 = cognitive2 if (cognitive2 != .c) & (cognitive3 == .c)
replace cognitive4 = cognitive3 if (cognitive3 != .c) & (cognitive4 == .c)
replace cognitive5 = cognitive4 if (cognitive4 != .c) & (cognitive5 == .c)
replace cognitive6 = cognitive5 if (cognitive5 != .c) & (cognitive6 == .c)
replace cognitive3 = .c if (part_08==0) & (part_11==0) & (part_14==0) & (part_17==0)
replace cognitive4 = .c if (part_11==0) & (part_14==0) & (part_17==0)
replace cognitive5 = .c if (part_14==0) & (part_17==0)
replace cognitive6 = .c if (part_17==0)

replace dependency2 = dependency1 if (dependency1 != .c) & (dependency2 == .c)
replace dependency3 = dependency2 if (dependency2 != .c) & (dependency3 == .c)
replace dependency4 = dependency3 if (dependency3 != .c) & (dependency4 == .c)
replace dependency5 = dependency4 if (dependency4 != .c) & (dependency5 == .c)
replace dependency6 = dependency5 if (dependency5 != .c) & (dependency6 == .c)
replace dependency3 = .c if (part_08==0) & (part_11==0) & (part_14==0) & (part_17==0)
replace dependency4 = .c if (part_11==0) & (part_14==0) & (part_17==0)
replace dependency5 = .c if (part_14==0) & (part_17==0)
replace dependency6 = .c if (part_17==0)

replace vitality2 = vitality1 if (vitality1 != .c) & (vitality2 == .c)
replace vitality3 = vitality2 if (vitality2 != .c) & (vitality3 == .c)
replace vitality4 = vitality3 if (vitality3 != .c) & (vitality4 == .c)
replace vitality5 = vitality4 if (vitality4 != .c) & (vitality5 == .c)
replace vitality6 = vitality5 if (vitality5 != .c) & (vitality6 == .c)
replace vitality3 = .c if (part_08==0) & (part_11==0) & (part_14==0) & (part_17==0)
replace vitality4 = .c if (part_11==0) & (part_14==0) & (part_17==0)
replace vitality5 = .c if (part_14==0) & (part_17==0)
replace vitality6 = .c if (part_17==0)

replace pa2 = pa1 if (pa1 != .c) & (pa2 == .c)
replace pa3 = pa2 if (pa2 != .c) & (pa3 == .c)
replace pa4 = pa3 if (pa3 != .c) & (pa4 == .c)
replace pa5 = pa4 if (pa4 != .c) & (pa5 == .c)
replace pa6 = pa5 if (pa5 != .c) & (pa6 == .c)
replace pa3 = .c if (part_08==0) & (part_11==0) & (part_14==0) & (part_17==0)
replace pa4 = .c if (part_11==0) & (part_14==0) & (part_17==0)
replace pa5 = .c if (part_14==0) & (part_17==0)
replace pa6 = .c if (part_17==0)

alpha freedom1 needs1 adaption1 serenity1 cognitive1 dependency1 vitality1, item
alpha freedom2 needs2 adaption2 serenity2 cognitive2 dependency2 vitality2, item
alpha freedom3 needs3 adaption3 serenity3 cognitive3 dependency3 vitality3, item
alpha freedom4 needs4 adaption4 serenity4 cognitive4 dependency4 vitality4, item
alpha freedom5 needs5 adaption5 serenity5 cognitive5 dependency5 vitality5, item
alpha freedom6 needs6 adaption6 serenity6 cognitive6 dependency6 vitality6, item


************************************************************************************************
*** Independent variables

* Marital and partnership status

* Marital status
*1996
tab1 v9_11 v9_14 v9_19 v9_24 v9_29
generate marital1 = .c
replace marital1 = 1 if v9_11==1
replace marital1 = 2 if v9_14==1
replace marital1 = 3 if v9_19==1
replace marital1 = 4 if v9_24==1
replace marital1 = .c if v9_11==0 & v9_14==0 & v9_19==0 & v9_24==0 & v9_29==0
tab marital1

*2002
rename w18_11 marital2
tab marital2

*2008
rename x200 marital3
tab marital3

*2011
rename gc200 marital4
tab marital4

*2014
tab hc200
rename hc200 marital5
replace marital5 = 1 if famstand_14==1
replace marital5 = 2 if famstand_14==2
replace marital5 = 3 if famstand_14==3
replace marital5 = 4 if famstand_14==4
replace marital5 = 1 if fallnum==3001164
tab marital5

*2017
rename famstand_17 marital6
tab marital6

label define MARITAL 1 "married, living together" 2 "married, living separate" 3 "divorced" 4 "widowed"

foreach X of varlist marital1 marital2 marital3 marital4 marital5 marital6 { 
	label variable `X' "Marital status"
	label values `X' MARITAL
}

* Relationship status

*1996
tab1 v9_30 v9_35
generate relstatus1 = v9_30
replace relstatus1 = 1 if v9_35==1
replace relstatus1 = 2 if v9_35==2
tab relstatus1

*2002
tab1 w18_40 w18_45
generate relstatus2 = w18_40
replace relstatus2 = 1 if w18_45==1
replace relstatus2 = 2 if w18_45==2
tab relstatus2

*2008
tab1 x200o x202
generate relstatus3 = .c
replace relstatus3 = 1 if x200o==1
replace relstatus3 = 2 if x200o==2
replace relstatus3 = 1 if x202==1
replace relstatus3 = 2 if x202==2
tab relstatus3

*2011
tab1 gc200o gc202
generate relstatus4 = gc200o
replace relstatus4 = 1 if gc202==1
replace relstatus4 = 2 if gc202==2
tab relstatus4

*2014
tab partner_14
tab2 partner_14 marital5
generate relstatus5 = .c
replace relstatus5 = 1 if (partner_14==2) & (marital5!=1)
replace relstatus5 = 1 if partner_14==3
replace relstatus5 = 2 if partner_14==1
tab relstatus5

*2017
tab partner_17
tab2 partner_17 marital6
generate relstatus6 = .c 
replace relstatus6 = 1 if (partner_17==2) & (marital6!=1)
replace relstatus6 = 1 if partner_17==3
replace relstatus6 = 2 if partner_17==1
tab relstatus6

label define RELSTATUS 1 "Yes" 2 "No" 

foreach X of varlist relstatus1-relstatus6 { 
	label variable `X' "Living in a nonmarital relationship"
	label values `X' RELSTATUS
	}
	
* Combination of marital and relationship status
foreach X of numlist 1/6 {
	generate relationship`X' = .c 
	replace relationship`X' = 1 if marital`X'==1 
	replace relationship`X' = 2 if (marital`X'==2) & (relstatus`X'==2) 
	replace relationship`X' = 3 if (marital`X'==3) & (relstatus`X'==2) 
	replace relationship`X' = 4 if (marital`X'==4) & (relstatus`X'==2) 
	replace relationship`X' = 5 if (marital`X'==2) & (relstatus`X'==1) 
	replace relationship`X' = 6 if (marital`X'==3) & (relstatus`X'==1) 
	replace relationship`X' = 7 if (marital`X'==4) & (relstatus`X'==1) 
}

label define RELATIONSHIP 1 " married, living together" 2 "married, living separate, single" 3 "divorced, single" 4 "widowed, single" 5 "married, living separate, partnered" 6 "divorced, partnered" 7 "widowed, partnered" 

foreach X of varlist relationship1-relationship6 { 
	label variable `X' "Combined relationship and marital status"
	label values `X' RELATIONSHIP
	}

* Generating year variables to control consistency of the relationship status over time
generate yow1 = v9_25 + 1900
generate yow2 = w18_32 
generate yow3 = x200j_2 
generate yow4 = gc200j_2 
generate yow5 = hc252_y
replace yow5 = hc282d_y if yow5==.c
replace yow5 = hc252_y if yow5==.c
replace yow5 = hc283m_y1 if (yow5==.c) & (hc283k1==4)
replace yow5 = hc283m_y2 if (yow5==.c) & (hc283k2==4)
generate yow6 = ic252_y 
replace yow6 = ic282d_y if yow6==.c
replace yow6 = ic252_y if yow6==.c
replace yow6 = ic283m_y1 if (yow6==.c) & (ic283k1==4)
replace yow6 = ic283m_y2 if (yow6==.c) & (ic283k2==4)

foreach X of varlist yow1-yow6 {
	label variable `X' "Year of death of last partner"
	} 
	
generate yod1 = v9_20 + 1900
generate yod2 = w18_24 
generate yod3 = x200g_2 
generate yod4 = gc200g_2 
generate yod5 = hc250_y 
replace yod5 = hc280ab if yod5==.c
replace yod5 = hc282c_y if yod5==.c
replace yod5 = hc283l_y1 if (yod5==.c)
replace yod5 = hc283l_y2 if (yod5==.c)
generate yod6 = ic250_y 
replace yod6 = ic280ab if yod6==.c
replace yod6 = ic282c_y if yod6==.c
replace yod6 = ic283l_y1 if yod6==.c
replace yod6 = ic283l_y2 if yod6==.c

foreach X of varlist yod1-yod6 {
	label variable `X' "Year of last divorce"
	} 

generate yos1 = v11_28 + 1900 
generate yos2 = w18_16
replace yos2 = w18_1354 if yos2==.c
generate yos3 = x200d_2
replace yos3 = x237_2 if yos3==.c
generate yos4 = gc200d_2 
replace yos4 = gc237_2 if yos4==.c
generate yos5 = hc251_y
replace yos5 = hc273 if (yos5==.c) & (hc282b==3)
replace yos5 = hc282d_y if (yos5==.c) & (hc282b==3)
replace yos5 = hc283m_y1 if (yos5==.c) & (hc283k1==3)
replace yos5 = hc283m_y2 if (yos5==.c) & (hc283k2==3)
generate yos6 = ic251_y
replace yos6 = ic273 if (yos6==.c) & (ic282b==3)
replace yos6 = ic282d_y if (yos6==.c) & (ic282b==3)
replace yos6 = ic283m_y1 if (yos6==.c) & (ic283k1==3)
replace yos6 = ic283m_y2 if (yos6==.c) & (ic283k2==3)

foreach X of varlist yos1-yos6 {
	label variable `X' "Year of last separation"
	} 
	
generate yor1 = v9_38 + 1900
generate yor2 = w18_48 
generate yor3 = x203b_2 
generate yor4 = gc203b_2 
generate yor5 = hc204_y 
replace yor5 = hc283b_y1 if (hc283a1==1)
replace yor5 = hc283b_y2 if (hc283n1==1)
generate yor6 = ic204_y
replace yor6 = ic283b_y1 if (ic283a1==1)
replace yor6 = ic283b_y2 if (ic283n1==1)

foreach X of varlist yor1-yor6 {
	label variable `X' "Year of last transition to new partnership"
	} 	
	
generate yom1 = v9_12 + 1900
generate yom2 = w18_12
generate yom3 = x200a_2 
generate yom4 = gc200a_2 
generate yom5 = hc253_y
replace yom5 = hc281e_y if yom5==.c
replace yom5 = hc203_y if yom5==.c
replace yom5 = hc283h_y1 if (hc283g1==1) & (yom5==.c)
replace yom5 = hc283h_y2 if (hc283g2==1) & (yom5==.c)
generate yom6 = ic253_y
replace yom6 = ic281e_y if yom6==.c
replace yom6 = ic203_y if yom6==.c
replace yom6 = ic283h_y1 if (ic283g1==1) & (yom6==.c)
replace yom6 = ic283h_y2 if (ic283g2==1) & (yom6==.c)

foreach X of varlist yom1-yom6 {
	label variable `X' "Year of last marriage"
	} 

* Generating a variable to control for the participation profile
replace participation=222212 if part_96==0 & part_02==0 & part_08==0 & part_11==0 & (part_14==1 | part_14==2) & part_17==0
replace participation=222211 if part_96==0 & part_02==0 & part_08==0 & part_11==0 & (part_14==1 | part_14==2) & part_17==2
replace participation=221221 if part_96==0 & part_02==0 & (part_08==1 | part_08==2) & part_11==0 & part_14==0 & part_17==2
replace participation=221212 if part_96==0 & part_02==0 & (part_08==1 | part_08==2) & part_11==0 & (part_14==1 | part_14==2) & part_17==0
replace participation=221211 if part_96==0 & part_02==0 & (part_08==1 | part_08==2) & part_11==0 & (part_14==1 | part_14==2) & part_17==2
replace participation=221122 if part_96==0 & part_02==0 & (part_08==1 | part_08==2) & part_11==2 & part_14==0 & part_17==0
replace participation=221121 if part_96==0 & part_02==0 & (part_08==1 | part_08==2) & part_11==2 & part_14==0 & part_17==2
replace participation=221112 if part_96==0 & part_02==0 & (part_08==1 | part_08==2) & part_11==2 & (part_14==1 | part_14==2) & part_17==0
replace participation=221111 if part_96==0 & part_02==0 & (part_08==1 | part_08==2) & part_11==2 & (part_14==1 | part_14==2) & part_17==2
replace participation=212222 if part_96==0 & (part_02==1 | part_02==2 | part_02==9) & part_08==0 & part_11==0 & part_14==0 & part_17==0
replace participation=212221 if part_96==0 & (part_02==1 | part_02==2 | part_02==9) & part_08==0 & part_11==0 & part_14==0 & part_17==2
replace participation=212212 if part_96==0 & (part_02==1 | part_02==2 | part_02==9) & part_08==0 & part_11==0 & (part_14==1 | part_14==2) & part_17==0
replace participation=212211 if part_96==0 & (part_02==1 | part_02==2 | part_02==9) & part_08==0 & part_11==0 & (part_14==1 | part_14==2) & part_17==2
replace participation=212122 if part_96==0 & (part_02==1 | part_02==2 | part_02==9) & part_08==0 & part_11==2 & part_14==0 & part_17==0
replace participation=212121 if part_96==0 & (part_02==1 | part_02==2 | part_02==9) & part_08==0 & part_11==2 & part_14==0 & part_17==2
replace participation=212112 if part_96==0 & (part_02==1 | part_02==2 | part_02==9) & part_08==0 & part_11==2 & (part_14==1 | part_14==2) & part_17==0
replace participation=212111 if part_96==0 & (part_02==1 | part_02==2 | part_02==9) & part_08==0 & part_11==2 & (part_14==1 | part_14==2) & part_17==2
replace participation=211222 if part_96==0 & (part_02==1 | part_02==2 | part_02==9) & (part_08==1 | part_08==2) & part_11==0 & part_14==0 & part_17==0
replace participation=211221 if part_96==0 & (part_02==1 | part_02==2 | part_02==9) & (part_08==1 | part_08==2) & part_11==0 & part_14==0 & part_17==2
replace participation=211212 if part_96==0 & (part_02==1 | part_02==2 | part_02==9) & (part_08==1 | part_08==2) & part_11==0 & (part_14==1 | part_14==2) & part_17==0
replace participation=211211 if part_96==0 & (part_02==1 | part_02==2 | part_02==9) & (part_08==1 | part_08==2) & part_11==0 & (part_14==1 | part_14==2) & part_17==2
replace participation=211122 if part_96==0 & (part_02==1 | part_02==2 | part_02==9) & (part_08==1 | part_08==2) & part_11==2 & part_14==0 & part_17==0
replace participation=211121 if part_96==0 & (part_02==1 | part_02==2 | part_02==9) & (part_08==1 | part_08==2) & part_11==2 & part_14==0 & part_17==2
replace participation=211112 if part_96==0 & (part_02==1 | part_02==2 | part_02==9) & (part_08==1 | part_08==2) & part_11==2 & (part_14==1 | part_14==2) & part_17==0
replace participation=211111 if part_96==0 & (part_02==1 | part_02==2 | part_02==9) & (part_08==1 | part_08==2) & part_11==2 & (part_14==1 | part_14==2) & part_17==2
replace participation=122222 if part_96==1 & part_02==0 & part_08==0 & part_11==0 & part_14==0 & part_17==0
replace participation=122221 if part_96==1 & part_02==0 & part_08==0 & part_11==0 & part_14==0 & part_17==2
replace participation=122212 if part_96==1 & part_02==0 & part_08==0 & part_11==0 & (part_14==1 | part_14==2) & part_17==0
replace participation=122211 if part_96==1 & part_02==0 & part_08==0 & part_11==0 & (part_14==1 | part_14==2) & part_17==2
replace participation=122122 if part_96==1 & part_02==0 & part_08==0 & part_11==2 & part_14==0 & part_17==0
replace participation=122121 if part_96==1 & part_02==0 & part_08==0 & part_11==2 & part_14==0 & part_17==2
replace participation=122112 if part_96==1 & part_02==0 & part_08==0 & part_11==2 & (part_14==1 | part_14==2) & part_17==0
replace participation=122111 if part_96==1 & part_02==0 & part_08==0 & part_11==2 & (part_14==1 | part_14==2) & part_17==2
replace participation=121222 if part_96==1 & part_02==0 & (part_08==1 | part_08==2) & part_11==0 & part_14==0 & part_17==0
replace participation=121212 if part_96==1 & part_02==0 & (part_08==1 | part_08==2) & part_11==0 & (part_14==1 | part_14==2) & part_17==0
replace participation=121211 if part_96==1 & part_02==0 & (part_08==1 | part_08==2) & part_11==0 & (part_14==1 | part_14==2) & part_17==2
replace participation=121122 if part_96==1 & part_02==0 & (part_08==1 | part_08==2) & part_11==2 & part_14==0 & part_17==0
replace participation=121121 if part_96==1 & part_02==0 & (part_08==1 | part_08==2) & part_11==2 & part_14==0 & part_17==2
replace participation=121112 if part_96==1 & part_02==0 & (part_08==1 | part_08==2) & part_11==2 & (part_14==1 | part_14==2) & part_17==0
replace participation=121111 if part_96==1 & part_02==0 & (part_08==1 | part_08==2) & part_11==2 & (part_14==1 | part_14==2) & part_17==2
replace participation=112222 if part_96==1 & (part_02==1 | part_02==2 | part_02==9) & part_08==0 & part_11==0 & part_14==0 & part_17==0
replace participation=112221 if part_96==1 & (part_02==1 | part_02==2 | part_02==9) & part_08==0 & part_11==0 & part_14==0 & part_17==2
replace participation=112212 if part_96==1 & (part_02==1 | part_02==2 | part_02==9) & part_08==0 & part_11==0 & (part_14==1 | part_14==2) & part_17==0
replace participation=112211 if part_96==1 & (part_02==1 | part_02==2 | part_02==9) & part_08==0 & part_11==0 & (part_14==1 | part_14==2) & part_17==2
replace participation=112122 if part_96==1 & (part_02==1 | part_02==2 | part_02==9) & part_08==0 & part_11==2 & part_14==0 & part_17==0
replace participation=112121 if part_96==1 & (part_02==1 | part_02==2 | part_02==9) & part_08==0 & part_11==2 & part_14==0 & part_17==2
replace participation=112112 if part_96==1 & (part_02==1 | part_02==2 | part_02==9) & part_08==0 & part_11==2 & (part_14==1 | part_14==2) & part_17==0
replace participation=112111 if part_96==1 & (part_02==1 | part_02==2 | part_02==9) & part_08==0 & part_11==2 & (part_14==1 | part_14==2) & part_17==2
replace participation=111222 if part_96==1 & (part_02==1 | part_02==2 | part_02==9) & (part_08==1 | part_08==2) & part_11==0 & part_14==0 & part_17==0
replace participation=111221 if part_96==1 & (part_02==1 | part_02==2 | part_02==9) & (part_08==1 | part_08==2) & part_11==0 & part_14==0 & part_17==2
replace participation=111212 if part_96==1 & (part_02==1 | part_02==2 | part_02==9) & (part_08==1 | part_08==2) & part_11==0 & (part_14==1 | part_14==2) & part_17==0
replace participation=111211 if part_96==1 & (part_02==1 | part_02==2 | part_02==9) & (part_08==1 | part_08==2) & part_11==0 & (part_14==1 | part_14==2) & part_17==2
replace participation=111122 if part_96==1 & (part_02==1 | part_02==2 | part_02==9) & (part_08==1 | part_08==2) & part_11==2 & part_14==0 & part_17==0
replace participation=111121 if part_96==1 & (part_02==1 | part_02==2 | part_02==9) & (part_08==1 | part_08==2) & part_11==2 & part_14==0 & part_17==2
replace participation=111112 if part_96==1 & (part_02==1 | part_02==2 | part_02==9) & (part_08==1 | part_08==2) & part_11==2 & (part_14==1 | part_14==2) & part_17==0
replace participation=111111 if part_96==1 & (part_02==1 | part_02==2 | part_02==9) & (part_08==1 | part_08==2) & part_11==2 & (part_14==1 | part_14==2) & part_17==2

label variable participation "Participation profile, 1 means participation, 2 means no participation"


* Controlling the variable for combined relationship and marital status
list relationship1 marital1 relstatus1 yom1 participation if relationship1==1   
/// married, living together
list relationship1 marital1 relstatus1 yom1 yos1 participation if relationship1==2   
/// married, living separate, single
list relationship1 marital1 relstatus1 yom1 yod1 participation if relationship1==3   
/// divorced, single
list relationship1 marital1 relstatus1 yom1 yow1 participation if relationship1==4   
/// widowed, single
list relationship1 marital1 relstatus1 yom1 yos1 yor1 participation if relationship1==5   
/// married, living separate, partnered
list relationship1 marital1 relstatus1 yom1 yod1 yor1 participation if relationship1==6   
/// divorced, partnered
list relationship1 marital1 relstatus1 yom1 yow1 yor1 participation if relationship1==7   
/// widowed, partnered

list relationship2 marital2 relstatus2 yom2 participation if relationship2==1   
/// married, living together
list relationship2 marital2 relstatus2 yom2 yos2 participation if relationship2==2   
/// married, living separate, single
list relationship2 marital2 relstatus2 yom2 yod2 participation if relationship2==3   
/// divorced, single
list relationship2 marital2 relstatus2 yom2 yow2 participation if relationship2==4   
/// widowed, single
list relationship2 marital2 relstatus2 yom2 yos2 yor2 participation if relationship2==5   
/// married, living separate, partnered
list relationship2 marital2 relstatus2 yom2 yod2 yor2 participation if relationship2==6   
/// divorced, partnered
list relationship2 marital2 relstatus2 yom2 yow2 yor2 participation if relationship2==7   
/// widowed, partnered

list relationship3 marital3 relstatus3 yom3 participation if relationship3==1   
/// married, living together
list relationship3 marital3 relstatus3 yom3 yos3 participation if relationship3==2   
/// married, living separate, single
list relationship3 marital3 relstatus3 yom3 yod3 participation if relationship3==3   
/// divorced, single
list relationship3 marital3 relstatus3 yom3 yow3 participation if relationship3==4   
/// widowed, single
list relationship3 marital3 relstatus3 yom3 yos3 yor3 participation if relationship3==5   
/// married, living separate, partnered
list relationship3 marital3 relstatus3 yom3 yod3 yor3 participation if relationship3==6   
/// divorced, partnered
list relationship3 marital3 relstatus3 yom3 yow3 yor3 participation if relationship3==7   
/// widowed, partnered

list relationship4 marital4 relstatus4 yom4 participation if relationship4==1   
/// married, living together
list relationship4 marital4 relstatus4 yom4 yos4 participation if relationship4==2   
/// married, living separate, single
list relationship4 marital4 relstatus4 yom4 yod4 participation if relationship4==3   
/// divorced, single
list relationship4 marital4 relstatus4 yom4 yow4 participation if relationship4==4   
/// widowed, single
list relationship4 marital4 relstatus4 yom4 yos4 yor4 participation if relationship4==5   
/// married, living separate, partnered
list relationship4 marital4 relstatus4 yom4 yod4 yor4 participation if relationship4==6   
/// divorced, partnered
list relationship4 marital4 relstatus4 yom4 yow4 yor4 participation if relationship4==7   
/// widowed, partnered

list relationship5 marital5 relstatus5 yom5 participation if relationship5==1   
/// married, living together
list relationship5 marital5 relstatus5 yom5 yos5 participation if relationship5==2   
/// married, living separate, single
list relationship5 marital5 relstatus5 yom5 yod5 participation if relationship5==3   
/// divorced, single
list relationship5 marital5 relstatus5 yom5 yow5 participation if relationship5==4   
/// widowed, single
list relationship5 marital5 relstatus5 yom5 yos5 yor5 participation if relationship5==5   
/// married, living separate, partnered
list relationship5 marital5 relstatus5 yom5 yod5 yor5 participation if relationship5==6   
/// divorced, partnered
list relationship5 marital5 relstatus5 yom5 yow5 yor5 participation if relationship5==7   
/// widowed, partnered

list relationship6 marital6 relstatus6 yom6 participation if relationship6==1   
/// married, living together
list relationship6 marital6 relstatus6 yom6 yos6 participation if relationship6==2   
/// married, living separate, single
list relationship6 marital6 relstatus6 yom6 yod6 participation if relationship6==3   
/// divorced, single
list relationship6 marital6 relstatus6 yom6 yow6 participation if relationship6==4   
/// widowed, single
list relationship6 marital6 relstatus6 yom6 yos6 yor6 participation if relationship6==5   
/// married, living separate, partnered
list relationship6 marital6 relstatus6 yom6 yod6 yor6 participation if relationship6==6   
/// divorced, partnered
list relationship6 marital6 relstatus6 yom6 yow6 yor6 participation if relationship6==7   
/// widowed, partnered

* Controlling relationship courses
foreach X of numlist 1/6 {
	list relationship1 relationship2 relationship3 relationship4 relationship5 relationship6 yom`X' yos`X' yod`X' yow`X' yor`X' participation if relationship`X'==1   
	list relationship1 relationship2 relationship3 relationship4 relationship5 relationship6 yom`X' yos`X' yod`X' yow`X' yor`X' participation if relationship`X'==2   
	list relationship1 relationship2 relationship3 relationship4 relationship5 relationship6 yom`X' yos`X' yod`X' yow`X' yor`X' participation if relationship`X'==3   
	list relationship1 relationship2 relationship3 relationship4 relationship5 relationship6 yom`X' yos`X' yod`X' yow`X' yor`X' participation if relationship`X'==4   
	list relationship1 relationship2 relationship3 relationship4 relationship5 relationship6 yom`X' yos`X' yod`X' yow`X' yor`X' participation if relationship`X'==5   
	list relationship1 relationship2 relationship3 relationship4 relationship5 relationship6 yom`X' yos`X' yod`X' yow`X' yor`X' participation if relationship`X'==6   
	list relationship1 relationship2 relationship3 relationship4 relationship5 relationship6 yom`X' yos`X' yod`X' yow`X' yor`X' participation if relationship`X'==7   
}

* Correcting invalid or missing relationship states, based on the control for missing values, for invalid values and for consistency
replace relationship1 = 1 if fallnum==1003180

foreach X of numlist 1002079 1004105 {
	replace relationship2 = 1 if fallnum==`X'
}

foreach X of numlist 1001743 1002131 1002867 1004105 2000632 {
	replace relationship3 = 1 if fallnum==`X'
}

foreach X of numlist 1002131 1002867 2000959 {
	replace relationship4 = 1 if fallnum==`X'
}

foreach X of numlist 2002117 2002394 {
	replace relationship5 = 1 if fallnum==`X'
}

foreach X of numlist 1001448 1003366 {
	replace relationship2 = 2 if fallnum==`X'
}

foreach X of numlist 1001448 1003366 {
	replace relationship3 = 2 if fallnum==`X'
}

replace relationship4 = 2 if fallnum==3001330

foreach X of numlist 1000809 1000854 1002504 1001736 {
	replace relationship2 = 3 if fallnum==`X'
}

foreach X of numlist 1001718 1001962 1002552 1002921 1004754 2000788 2001276 2001731 2003289 3000839 3003295 {
	replace relationship3 = 3 if fallnum==`X'
}

foreach X of numlist 1001718 1001962 1002552 1002846 1002921 1004754 2000788 2003289 {
	replace relationship4 = 3 if fallnum==`X'
}

foreach X of numlist 1002921 3002311 {
	replace relationship5 = 3 if fallnum==`X'
}

foreach X of numlist 1000410 1004688 {
	replace relationship1 = 4 if fallnum==`X'
}

foreach X of numlist 1001771 1001680 1002760 1003699 1004062 {
	replace relationship2 = 4 if fallnum==`X'
}

foreach X of numlist 1000444 1001104 1001423 1001829 1002262 1002889 1002261 1002870 1003257 1003421 1004062 1004688 2002939 3002268 3003408 {
	replace relationship3 = 4 if fallnum==`X'
}

foreach X of numlist 1001104 1004062 1004688 2002768 3000498 3000686 3002483 3002731 3005559 3005991 3006015 3006182 {
	replace relationship4 = 4 if fallnum==`X'
}

foreach X of numlist 1001104 1003069 1004688 2002117 2002602 2002394 3000732 3001993 3003029 3004280 3004691 3005405 3006182 4003310 {
	replace relationship5 = 4 if fallnum==`X'
}

replace relationship6 = 4 if fallnum==2002754

foreach X of numlist 3000818 3003059 {
	replace relationship3 = 5 if fallnum==`X'
}

foreach X of numlist 1002131 1002216 1002867 {
	replace relationship2 = 6 if fallnum==`X'
}

foreach X of numlist 2001253 3004148 {
	replace relationship3 = 6 if fallnum==`X'
}

foreach X of numlist 1002504 2001757 {
	replace relationship5 = 6 if fallnum==`X'
}

foreach X of numlist 1001730 1001843 {
	replace relationship2 = 7 if fallnum==`X'
}

foreach X of numlist 1001771 2002362 3000219 3000342 3001402 3006156 {
	replace relationship3 = 7 if fallnum==`X'
}

foreach X of numlist 1002261 1004233 3004047 3004280 {
	replace relationship4 = 7 if fallnum==`X'
}

replace relationship5 = 7 if fallnum==3003950

replace relationship3 = .c if fallnum==1004688
replace relationship4 = .c if fallnum==1004688
replace relationship5 = .c if fallnum==1004688

* Deleting respondents with missings infromation even though they were interviewes or with inconsistent relationship courses  
foreach X of numlist 1002230 2001283 3001340 {
	drop if fallnum == `X'
}

* Gender
drop v1_11 w1_11 x1 gc1 hc1 ic1

recode gender (1=0) (2=1)

label define gender 0 "Men" 1 "Women" 
label variable gender "Gender"
label values gender gender


************************************************************************************************
*** Control variables
* Educational attainment
rename isced education
drop isced_96 isced_02 isced_08 isced_11 isced_14 isced_17

recode education (1=0) (2=1) (3=2)

label define education 0 "low (ISCED 0-2)" 1 "medium (ISCED 3-4)" 2 "high (ISCED 5-6)" 
label values education education


* Migration experience
rename migrat migrationshintergrund

generate migrat = .c
replace migrat = 0 if (v16_56==1) | (w25_11==1) | (x325==1) | (hc25a==1) | (migrationshintergrund==0)  
replace migrat = 1 if (v16_56==2) | (v16_56==3) | (v16_56==4) | (w25_11==2) | (w25_11==3) | (w25_11==4) | (x325==2) | (x325==3) | (x325==4) | (hc25a==2) | (hc25a==3) | (hc25a==4) 
replace migrat = 0 if (w25_12 < 1950) | (x326 < 1950) | (hc25b < 1950) 

label define MIGRATION 0 "No" 1 "Yes" 
label variable migrat "Migration experience"
label values migrat MIGRATION


* Age when interviewed
rename altervoll_96 age1
rename altervoll_02 age2
rename altervoll_08 age3
rename altervoll_11 age4
rename altervoll_14 age5
rename altervoll_17 age6

foreach X of varlist age1 age2 age3 age4 age5 age6 {
	label variable `X' "Age"
	} 
	
	
* Grandparenthood
gen grandparents1 = .c
replace grandparents1=0 if anzenk_96==0
replace grandparents1=1 if (anzenk_96!=0) & (part_96==1)

gen grandparents2 = .c
replace grandparents2=0 if anzenk_02==0
replace grandparents2=1 if (anzenk_02!=0) & (part_02!=0)

gen grandparents3 = .c
replace grandparents3=0 if anzenk_08==0
replace grandparents3=1 if (anzenk_08!=0) & (part_08!=0)

gen grandparents4 = .c
replace grandparents4=0 if anzenk_11==0
replace grandparents4=1 if (anzenk_11!=0) & (part_11!=0)

gen grandparents5 = .c
replace grandparents5=0 if anzenk_14==0
replace grandparents5=1 if (anzenk_14!=0) & (part_14!=0)

gen grandparents6 = .c
replace grandparents6=0 if anzenk_17==0
replace grandparents6=1 if (anzenk_17!=0) & (part_17!=0)

label define grandparents 0 "No" 1 "Yes" 

foreach X of varlist grandparents1 grandparents2 grandparents3 grandparents4 grandparents5 grandparents6 {
	label variable `X' "Grandparenthood"
	label values `X' grandparents
}

replace grandparents2 = grandparents1 if (grandparents1 != .c) & (grandparents2 == .c)
replace grandparents3 = grandparents2 if (grandparents2 != .c) & (grandparents3 == .c)
replace grandparents4 = grandparents3 if (grandparents3 != .c) & (grandparents4 == .c)
replace grandparents5 = grandparents4 if (grandparents4 != .c) & (grandparents5 == .c)
replace grandparents6 = grandparents5 if (grandparents5 != .c) & (grandparents6 == .c)
replace grandparents3 = .c if (part_08==0) & (part_11==0) & (part_14==0) & (part_17==0)
replace grandparents4 = .c if (part_11==0) & (part_14==0) & (part_17==0)
replace grandparents5 = .c if (part_14==0) & (part_17==0)
replace grandparents6 = .c if (part_17==0)


* Network size
rename nwgroesse_96 network1
rename nwgroesse_02 network2
rename nwgroesse_08 network3
rename nwgroesse_11 network4
rename nwgroesse_14 network5
rename nwgroesse_17 network6

replace network2 = network1 if (network1 != .c) & (network2 == .c)
replace network3 = network2 if (network2 != .c) & (network3 == .c)
replace network4 = network3 if (network3 != .c) & (network4 == .c)
replace network5 = network4 if (network4 != .c) & (network5 == .c)
replace network6 = network5 if (network5 != .c) & (network6 == .c)
replace network3 = .c if (part_08==0) & (part_11==0) & (part_14==0) & (part_17==0)
replace network4 = .c if (part_11==0) & (part_14==0) & (part_17==0)
replace network5 = .c if (part_14==0) & (part_17==0)
replace network6 = .c if (part_17==0)


* Physical health
generate health1 = .
replace health1 = anzphy_96 if (anzphy_96 != .f) & (anzphy_96 != .) 

generate health2 = .
replace health2 = anzphy_02 if (anzphy_02 != .c) & (anzphy_02 != .f) & (anzphy_02 != .) 

generate health3 = .
replace health3 = anzphy_08 if (anzphy_08 != .f) & (anzphy_08 != .) 

generate health4 = .
replace health4 = anzphy_11 if (anzphy_11 != .e) & (anzphy_11 != .f) & (anzphy_11 != .g) & (anzphy_11 != .) 

generate health5 = .
replace health5 = anzphy_14 if (anzphy_14 != .e) & (anzphy_14 != .f) & (anzphy_14 != .g) & (anzphy_14 != .) 

generate health6 = .
replace health6 = anzphy_17 if (anzphy_17 != .e) & (anzphy_17 != .f) & (anzphy_17 != .g) & (anzphy_17 != .) 

foreach X of varlist health1 health2 health3 health4 health5 health6 {
	label variable `X' "Physical health"
}

replace health2 = health1 if (health1 != .) & (health2 == .)
replace health3 = health2 if (health2 != .) & (health3 == .)
replace health4 = health3 if (health3 != .) & (health4 == .)
replace health5 = health4 if (health4 != .) & (health5 == .)
replace health6 = health5 if (health5 != .) & (health6 == .)

replace health3 = . if (part_08==0) & (part_11==0) & (part_14==0) & (part_17==0)
replace health4 = . if (part_11==0) & (part_14==0) & (part_17==0)
replace health5 = . if (part_14==0) & (part_17==0)
replace health6 = . if (part_17==0)

************************************************************************************************
*** Building variables to contruct analytical samples

* Number of prior marriages 
generate yearmarriage = v9_12+1900

generate n_mar2 = w71_107+1
replace n_mar2 = 1 if w71_106==1
replace n_mar2 = 1 if relationship2==1 & part_02==1

generate n_mar1 = 1 if relationship1==1
replace n_mar1 = n_mar2 if (yearmarriage == w18_12)

generate n_mar3 = x200ca+1
replace n_mar3 = 1 if x200c==1
replace n_mar3 = 1 if x200c==1

generate n_mar4 = gc200ca+1
replace n_mar4 = 1 if gc200c==1
replace n_mar4 = n_mar3 if (relationship3==1) & (relationship4==1)

generate n_mar5 = hc271+1
replace n_mar5 = n_mar2 if (hc280d==1) & ((part_02==1) | (part_02==2)) & (part_08==0) & (part_11==0) & (part_14==2)
replace n_mar5 = n_mar3 if (hc280d==1) & ((part_08==1) | (part_08==2)) & (part_11==0) & (part_14==2)
replace n_mar5 = n_mar4 if (hc280d==1) & (part_11==2) & (part_14==2)

generate n_mar6 = ic271+1
replace n_mar6 = n_mar2 if (ic280d==1) & ((part_02==1) | (part_02==2)) & (part_08==0) & (part_11==0) & (part_14==0) & (part_17==2)
replace n_mar6 = n_mar3 if (ic280d==1) & ((part_08==1) | (part_08==2)) & (part_11==0) & (part_14==0) & (part_17==2)
replace n_mar6 = n_mar5 if (ic280d==1) & (part_11==2) & (part_14==0) & (part_17==2)
replace n_mar6 = n_mar5 if (ic280d==1) & ((part_14==1) | (part_14==2)) & (part_17==2)

* Variable: Constantly being married
generate marriage = .c 
replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship3==1) & (relationship4==1) & (relationship5==1) & (relationship6==1) & (participation==111111) 
replace marriage = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==1) & (relationship4==1) & (relationship5==1) & (relationship6==1) & (participation==111111) 
replace marriage = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==.c) & (relationship4==1) & (relationship5==1) & (relationship6==1) & (participation==111111) 
replace marriage = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==.c) & (relationship4==.c) & (relationship5==1) & (relationship6==1) & (participation==111111) 
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship3==1) & (relationship4==1) & (relationship5==1) & (relationship6==1) & (participation==111111) 
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship3==1) & (relationship4==1) & (relationship5==1) & (relationship6==.c) & (participation==111111) 
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship3==1) & (relationship4==1) & (relationship5==.c) & (relationship6==.c) & (participation==111111) 
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship3==1) & (relationship4==.c) & (relationship5==.c) & (relationship6==.c) & (participation==111111) 
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship3==.c) & (relationship4==.c) & (relationship5==.c) & (relationship6==.c) & (participation==111111) 
replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship3==1) & (relationship4==1) & (relationship5==1) & (relationship6==.c) & (participation==111111) 
replace marriage = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==1) & (relationship4==1) & (relationship5==1) & (relationship6==.c) & (participation==111111) 
replace marriage = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==.c) & (relationship4==1) & (relationship5==1) & (relationship6==.c) & (participation==111111) 
replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship3==1) & (relationship4==1) & (relationship5==.c) & (relationship6==.c) & (participation==111111) 
replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship3==1) & (relationship4==.c) & (relationship5==.c) & (relationship6==.c) & (participation==111111) 

replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship3==1) & (relationship4==1) & (relationship5==1) & (participation==111112) 
replace marriage = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==1) & (relationship4==1) & (relationship5==1) & (participation==111112) 
replace marriage = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==.c) & (relationship4==1) & (relationship5==1) & (participation==111112) 
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship3==1) & (relationship4==1) & (relationship5==1) & (participation==111112)
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship3==1) & (relationship4==1) & (relationship5==.c) & (participation==111112)
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship3==1) & (relationship4==.c) & (relationship5==.c) & (participation==111112)
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship3==.c) & (relationship4==.c) & (relationship5==.c) & (participation==111112)
replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship3==1) & (relationship4==1) & (relationship5==.c) & (participation==111112)
replace marriage = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==1) & (relationship4==1) & (relationship5==.c) & (participation==111112)
replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship3==1) & (relationship4==.c) & (relationship5==.c) & (participation==111112)

replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship3==1) & (relationship4==1) & (relationship6==1) & (participation==111121) & (n_mar4==n_mar6)
replace marriage = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==1) & (relationship4==1) & (relationship6==1) & (participation==111121) & (n_mar4==n_mar6)
replace marriage = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==.c) & (relationship4==1) & (relationship6==1) & (participation==111121) & (n_mar4==n_mar6)
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship3==1) & (relationship4==1) & (relationship6==1) & (participation==111121) & (n_mar4==n_mar6)
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship3==1) & (relationship4==1) & (relationship6==.c) & (participation==111121) 
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship3==1) & (relationship4==.c) & (relationship6==.c) & (participation==111121) 
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship3==.c) & (relationship4==.c) & (relationship6==.c) & (participation==111121) 
replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship3==1) & (relationship4==1) & (relationship6==.c) & (participation==111121) 
replace marriage = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==1) & (relationship4==1) & (relationship6==.c) & (participation==111121) 
replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship3==1) & (relationship4==.c) & (relationship6==.c) & (participation==111121) 

replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship3==1) & (relationship4==1) & (participation==111122) 
replace marriage = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==1) & (relationship4==1) & (participation==111122) 
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship3==1) & (relationship4==1) & (participation==111122) 
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship3==1) & (relationship4==.c) & (participation==111122) 
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship3==.c) & (relationship4==.c) & (participation==111122) 
replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship3==1) & (relationship4==.c) & (participation==111122) 

replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship3==1) & (relationship5==1) & (relationship6==1) & (participation==111211) & (n_mar3==n_mar5)
replace marriage = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==1) & (relationship5==1) & (relationship6==1) & (participation==111211) & (n_mar3==n_mar5)
replace marriage = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==.c) & (relationship5==1) & (relationship6==1) & (participation==111211) 
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship3==1) & (relationship5==1) & (relationship6==1) & (participation==111211) & (n_mar3==n_mar5)
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship3==1) & (relationship5==1) & (relationship6==.c) & (participation==111211) & (n_mar3==n_mar5)
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship3==1) & (relationship5==.c) & (relationship6==.c) & (participation==111211) 
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship3==.c) & (relationship5==.c) & (relationship6==.c) & (participation==111211) 
replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship3==1) & (relationship5==1) & (relationship6==.c) & (participation==111211) & (n_mar3==n_mar5)
replace marriage = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==1) & (relationship5==1) & (relationship6==.c) & (participation==111211) & (n_mar3==n_mar5)
replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship3==1) & (relationship5==.c) & (relationship6==.c) & (participation==111211) 

replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship3==1) & (relationship5==1) & (participation==111212) & (n_mar3==n_mar5) 
replace marriage = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==1) & (relationship5==1) & (participation==111212) & (n_mar3==n_mar5) 
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship3==1) & (relationship5==1) & (participation==111212) & (n_mar3==n_mar5)
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship3==1) & (relationship5==.c) & (participation==111212) 
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship3==.c) & (relationship5==.c) & (participation==111212) 
replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship3==1) & (relationship5==.c) & (participation==111212) 

replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship3==1) & (relationship6==1) & (participation==111221) & (n_mar3==n_mar6)
replace marriage = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==1) & (relationship6==1) & (participation==111221) & (n_mar3==n_mar6)
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship3==1) & (relationship6==1) & (participation==111221) & (n_mar3==n_mar6)
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship3==1) & (relationship6==.c) & (participation==111221) 
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship3==.c) & (relationship6==.c) & (participation==111221) 
replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship3==1) & (relationship6==.c) & (participation==111221) 

replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship3==1) & (participation==111222) 
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship3==1) & (participation==111222) 
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship3==.c) & (participation==111222) 

replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship4==1) & (relationship5==1) & (relationship6==1) & (participation==112111) & (n_mar2==n_mar4)
replace marriage = 1 if (relationship1==.c) & (relationship2==.c) & (relationship4==1) & (relationship5==1) & (relationship6==1) & (participation==112111) 
replace marriage = 1 if (relationship1==.c) & (relationship2==.c) & (relationship4==.c) & (relationship5==1) & (relationship6==1) & (participation==112111) 
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship4==1) & (relationship5==1) & (relationship6==1) & (participation==112111) & (n_mar2==n_mar4)
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship4==1) & (relationship5==1) & (relationship6==.c) & (participation==112111) & (n_mar2==n_mar4)
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship4==1) & (relationship5==.c) & (relationship6==.c) & (participation==112111) & (n_mar2==n_mar4)
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship4==.c) & (relationship5==.c) & (relationship6==.c) & (participation==112111) 
replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship4==1) & (relationship5==1) & (relationship6==.c) & (participation==112111) & (n_mar2==n_mar4)
replace marriage = 1 if (relationship1==.c) & (relationship2==.c) & (relationship4==1) & (relationship5==1) & (relationship6==.c) & (participation==112111) 
replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship4==1) & (relationship5==.c) & (relationship6==.c) & (participation==112111) & (n_mar2==n_mar4)

replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship4==1) & (relationship5==1) & (participation==112112) & (n_mar2==n_mar4) 
replace marriage = 1 if (relationship1==.c) & (relationship2==.c) & (relationship4==1) & (relationship5==1) & (participation==112112) 
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship4==1) & (relationship5==1) & (participation==112112) & (n_mar2==n_mar4) 
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship4==1) & (relationship5==.c) & (participation==112112) & (n_mar2==n_mar4) 
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship4==.c) & (relationship5==.c) & (participation==112112)  
replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship4==1) & (relationship5==.c) & (participation==112112) & (n_mar2==n_mar4) 

replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship4==1) & (relationship6==1) & (participation==112121) & (n_mar2==n_mar4) & (n_mar4==n_mar6)
replace marriage = 1 if (relationship1==.c) & (relationship2==.c) & (relationship4==1) & (relationship6==1) & (participation==112121) & (n_mar4==n_mar6) 
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship4==1) & (relationship6==1) & (participation==112121) & (n_mar2==n_mar4) & (n_mar4==n_mar6)
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship4==1) & (relationship6==.c) & (participation==112121) & (n_mar2==n_mar4)
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship4==.c) & (relationship6==.c) & (participation==112121) 
replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship4==1) & (relationship6==.c) & (participation==112121) & (n_mar2==n_mar4)

replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship4==1) & (participation==112122) & (n_mar2==n_mar4) 
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship4==1) & (participation==112122) & (n_mar2==n_mar4) 
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship4==.c) & (participation==112122)

replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship5==1) & (relationship6==1) & (participation==112211) & (n_mar2==n_mar5)
replace marriage = 1 if (relationship1==.c) & (relationship2==.c) & (relationship5==1) & (relationship6==1) & (participation==112211)
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship5==1) & (relationship6==1) & (participation==112211) & (n_mar2==n_mar5)
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship5==1) & (relationship6==.c) & (participation==112211) & (n_mar2==n_mar5)
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship5==.c) & (relationship6==.c) & (participation==112211)
replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship5==1) & (relationship6==.c) & (participation==112211) & (n_mar2==n_mar5)

replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship5==1) & (participation==112212) & (n_mar2==n_mar5) 
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship5==1) & (participation==112212) & (n_mar2==n_mar5) 
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship5==.c) & (participation==112212) & (n_mar2==n_mar5)

replace marriage = 1 if (relationship1==.c) & (relationship2==1) & (relationship6==1) & (participation==112221) & (n_mar2==n_mar6)
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship6==1) & (participation==112221) & (n_mar2==n_mar6)
replace marriage = 1 if (relationship1==1) & (relationship2==1) & (relationship6==.c) & (participation==112221) & (n_mar2==n_mar6)

replace marriage = 1 if (relationship1==1) & (relationship2==1) & (participation==112222) 

replace marriage = 1 if (relationship1==.c) & (relationship3==1) & (relationship4==1) & (relationship5==1) & (relationship6==1) & (participation==121111)
replace marriage = 1 if (relationship1==.c) & (relationship3==.c) & (relationship4==1) & (relationship5==1) & (relationship6==1) & (participation==121111)
replace marriage = 1 if (relationship1==.c) & (relationship3==.c) & (relationship4==.c) & (relationship5==1) & (relationship6==1) & (participation==121111)
replace marriage = 1 if (relationship1==1) & (relationship3==1) & (relationship4==1) & (relationship5==1) & (relationship6==1) & (participation==121111) & (n_mar1==n_mar3)
replace marriage = 1 if (relationship1==1) & (relationship3==1) & (relationship4==1) & (relationship5==1) & (relationship6==.c) & (participation==121111) & (n_mar1==n_mar3)
replace marriage = 1 if (relationship1==1) & (relationship3==1) & (relationship4==1) & (relationship5==.c) & (relationship6==.c) & (participation==121111) & (n_mar1==n_mar3)
replace marriage = 1 if (relationship1==1) & (relationship3==1) & (relationship4==.c) & (relationship5==.c) & (relationship6==.c) & (participation==121111) & (n_mar1==n_mar3)
replace marriage = 1 if (relationship1==.c) & (relationship3==1) & (relationship4==1) & (relationship5==1) & (relationship6==.c) & (participation==121111)
replace marriage = 1 if (relationship1==.c) & (relationship3==.c) & (relationship4==1) & (relationship5==1) & (relationship6==.c) & (participation==121111)
replace marriage = 1 if (relationship1==.c) & (relationship3==1) & (relationship4==1) & (relationship5==.c) & (relationship6==.c) & (participation==121111)

replace marriage = 1 if (relationship1==.c) & (relationship3==1) & (relationship4==1) & (relationship5==1) & (participation==121112)
replace marriage = 1 if (relationship1==.c) & (relationship3==.c) & (relationship4==1) & (relationship5==1) & (participation==121112)
replace marriage = 1 if (relationship1==1) & (relationship3==1) & (relationship4==1) & (relationship5==1) & (participation==121112) & (n_mar1==n_mar3)
replace marriage = 1 if (relationship1==1) & (relationship3==1) & (relationship4==1) & (relationship5==.c) & (participation==121112) & (n_mar1==n_mar3)
replace marriage = 1 if (relationship1==1) & (relationship3==1) & (relationship4==.c) & (relationship5==.c) & (participation==121112) & (n_mar1==n_mar3)
replace marriage = 1 if (relationship1==.c) & (relationship3==1) & (relationship4==1) & (relationship5==.c) & (participation==121112)

replace marriage = 1 if (relationship1==.c) & (relationship3==1) & (relationship4==1) & (relationship6==1) & (participation==121121) & (n_mar4==n_mar6)
replace marriage = 1 if (relationship1==.c) & (relationship3==.c) & (relationship4==1) & (relationship6==1) & (participation==121121) & (n_mar4==n_mar6)
replace marriage = 1 if (relationship1==1) & (relationship3==1) & (relationship4==1) & (relationship6==1) & (participation==121121) & (n_mar1==n_mar3) & (n_mar4==n_mar6)
replace marriage = 1 if (relationship1==1) & (relationship3==1) & (relationship4==1) & (relationship6==.c) & (participation==121121) & (n_mar1==n_mar3)
replace marriage = 1 if (relationship1==1) & (relationship3==1) & (relationship4==.c) & (relationship6==.c) & (participation==121121) & (n_mar1==n_mar3)
replace marriage = 1 if (relationship1==.c) & (relationship3==1) & (relationship4==1) & (relationship6==.c) & (participation==121121)

replace marriage = 1 if (relationship1==.c) & (relationship3==1) & (relationship4==1) & (participation==121122) 
replace marriage = 1 if (relationship1==1) & (relationship3==1) & (relationship4==1) & (participation==121122) & (n_mar1==n_mar3) 
replace marriage = 1 if (relationship1==1) & (relationship3==1) & (relationship4==.c) & (participation==121122) & (n_mar1==n_mar3) 

replace marriage = 1 if (relationship1==.c) & (relationship3==1) & (relationship5==1) & (relationship6==1) & (participation==121211) & (n_mar3==n_mar5)
replace marriage = 1 if (relationship1==.c) & (relationship3==.c) & (relationship5==1) & (relationship6==1) & (participation==121211)
replace marriage = 1 if (relationship1==1) & (relationship3==1) & (relationship5==1) & (relationship6==1) & (participation==121211) & (n_mar1==n_mar3) & (n_mar3==n_mar5)
replace marriage = 1 if (relationship1==1) & (relationship3==1) & (relationship5==1) & (relationship6==.c) & (participation==121211) & (n_mar1==n_mar3) & (n_mar3==n_mar5)
replace marriage = 1 if (relationship1==1) & (relationship3==1) & (relationship5==.c) & (relationship6==.c) & (participation==121211) & (n_mar1==n_mar3)
replace marriage = 1 if (relationship1==.c) & (relationship3==1) & (relationship5==1) & (relationship6==.c) & (participation==121211) & (n_mar3==n_mar5)

replace marriage = 1 if (relationship1==.c) & (relationship3==1) & (relationship5==1) & (participation==121212) & (n_mar3==n_mar5)
replace marriage = 1 if (relationship1==1) & (relationship3==1) & (relationship5==1) & (participation==121212) & (n_mar1==n_mar3) & (n_mar3==n_mar5)
replace marriage = 1 if (relationship1==1) & (relationship3==1) & (relationship5==.c) & (participation==121212) & (n_mar1==n_mar3) 

replace marriage = 1 if (relationship1==1) & (relationship3==1) & (participation==121222) & (n_mar1==n_mar3)

replace marriage = 1 if (relationship1==.c) & (relationship4==1) & (relationship5==1) & (relationship6==1) & (participation==122111)
replace marriage = 1 if (relationship1==.c) & (relationship4==.c) & (relationship5==1) & (relationship6==1) & (participation==122111)
replace marriage = 1 if (relationship1==1) & (relationship4==1) & (relationship5==1) & (relationship6==1) & (participation==122111) & (n_mar1==n_mar4)
replace marriage = 1 if (relationship1==1) & (relationship4==1) & (relationship5==1) & (relationship6==.c) & (participation==122111) & (n_mar1==n_mar4)
replace marriage = 1 if (relationship1==1) & (relationship4==1) & (relationship5==.c) & (relationship6==.c) & (participation==122111) & (n_mar1==n_mar4)
replace marriage = 1 if (relationship1==.c) & (relationship4==1) & (relationship5==1) & (relationship6==.c) & (participation==122111)

replace marriage = 1 if (relationship1==.c) & (relationship4==1) & (relationship5==1) & (participation==122112) 
replace marriage = 1 if (relationship1==1) & (relationship4==1) & (relationship5==1) & (participation==122112) & (n_mar1==n_mar4)
replace marriage = 1 if (relationship1==1) & (relationship4==1) & (relationship5==.c) & (participation==122112) & (n_mar1==n_mar4)

replace marriage = 1 if (relationship1==.c) & (relationship4==1) & (relationship6==1) & (participation==122121) & (n_mar4==n_mar6)
replace marriage = 1 if (relationship1==1) & (relationship4==1) & (relationship6==1) & (participation==122121) & (n_mar1==n_mar4) & (n_mar4==n_mar6)
replace marriage = 1 if (relationship1==1) & (relationship4==1) & (relationship6==.c) & (participation==122121) & (n_mar1==n_mar4)

replace marriage = 1 if (relationship1==1) & (relationship4==1) & (participation==122122) & (n_mar1==n_mar4)

replace marriage = 1 if (relationship1==.c) & (relationship5==1) & (relationship6==1) & (participation==122211)
replace marriage = 1 if (relationship1==1) & (relationship5==1) & (relationship6==1) & (participation==122211) & (n_mar1==n_mar5)
replace marriage = 1 if (relationship1==1) & (relationship5==1) & (relationship6==.c) & (participation==122211) & (n_mar1==n_mar5)

replace marriage = 1 if (relationship1==1) & (relationship5==1) & (participation==122212) & (n_mar1==n_mar5)

replace marriage = 1 if (relationship1==1) & (relationship6==1) & (participation==122221) & (n_mar1==n_mar6)

replace marriage = 1 if (relationship2==.c) & (relationship3==1) & (relationship4==1) & (relationship5==1) & (relationship6==1) & (participation==211111)
replace marriage = 1 if (relationship2==.c) & (relationship3==.c) & (relationship4==1) & (relationship5==1) & (relationship6==1) & (participation==211111)
replace marriage = 1 if (relationship2==.c) & (relationship3==.c) & (relationship4==.c) & (relationship5==1) & (relationship6==1) & (participation==211111)
replace marriage = 1 if (relationship2==1) & (relationship3==1) & (relationship4==1) & (relationship5==1) & (relationship6==1) & (participation==211111)
replace marriage = 1 if (relationship2==1) & (relationship3==1) & (relationship4==1) & (relationship5==1) & (relationship6==.c) & (participation==211111)
replace marriage = 1 if (relationship2==1) & (relationship3==1) & (relationship4==1) & (relationship5==.c) & (relationship6==.c) & (participation==211111)
replace marriage = 1 if (relationship2==1) & (relationship3==1) & (relationship4==.c) & (relationship5==.c) & (relationship6==.c) & (participation==211111)
replace marriage = 1 if (relationship2==.c) & (relationship3==1) & (relationship4==1) & (relationship5==1) & (relationship6==.c) & (participation==211111)
replace marriage = 1 if (relationship2==.c) & (relationship3==1) & (relationship4==1) & (relationship5==.c) & (relationship6==.c) & (participation==211111)
replace marriage = 1 if (relationship2==.c) & (relationship3==.c) & (relationship4==1) & (relationship5==1) & (relationship6==.c) & (participation==211111)

replace marriage = 1 if (relationship2==.c) & (relationship3==1) & (relationship4==1) & (relationship5==1) & (participation==211112)
replace marriage = 1 if (relationship2==.c) & (relationship3==.c) & (relationship4==1) & (relationship5==1) & (participation==211112)
replace marriage = 1 if (relationship2==1) & (relationship3==1) & (relationship4==1) & (relationship5==1) & (participation==211112)
replace marriage = 1 if (relationship2==1) & (relationship3==1) & (relationship4==1) & (relationship5==.c) & (participation==211112)
replace marriage = 1 if (relationship2==1) & (relationship3==1) & (relationship4==.c) & (relationship5==.c) & (participation==211112)
replace marriage = 1 if (relationship2==.c) & (relationship3==1) & (relationship4==1) & (relationship5==.c) & (participation==211112)

replace marriage = 1 if (relationship2==.c) & (relationship3==1) & (relationship4==1) & (relationship6==1) & (participation==211121) & (n_mar4==n_mar6)
replace marriage = 1 if (relationship2==.c) & (relationship3==.c) & (relationship4==1) & (relationship6==1) & (participation==211121) & (n_mar4==n_mar6)
replace marriage = 1 if (relationship2==1) & (relationship3==1) & (relationship4==1) & (relationship6==1) & (participation==211121) & (n_mar4==n_mar6)
replace marriage = 1 if (relationship2==1) & (relationship3==1) & (relationship4==1) & (relationship6==.c) & (participation==211121)
replace marriage = 1 if (relationship2==1) & (relationship3==1) & (relationship4==.c) & (relationship6==.c) & (participation==211121)
replace marriage = 1 if (relationship2==.c) & (relationship3==1) & (relationship4==1) & (relationship6==.c) & (participation==211121)

replace marriage = 1 if (relationship2==.c) & (relationship3==1) & (relationship4==1) & (participation==211122)
replace marriage = 1 if (relationship2==1) & (relationship3==1) & (relationship4==1) & (participation==211122)
replace marriage = 1 if (relationship2==1) & (relationship3==1) & (relationship4==.c) & (participation==211122)

replace marriage = 1 if (relationship2==.c) & (relationship3==1) & (relationship5==1) & (relationship6==1) & (participation==211211) & (n_mar3==n_mar5)
replace marriage = 1 if (relationship2==.c) & (relationship3==.c) & (relationship5==1) & (relationship6==1) & (participation==211211)
replace marriage = 1 if (relationship2==1) & (relationship3==1) & (relationship5==1) & (relationship6==1) & (participation==211211) & (n_mar3==n_mar5)
replace marriage = 1 if (relationship2==1) & (relationship3==1) & (relationship5==1) & (relationship6==.c) & (participation==211211) & (n_mar3==n_mar5)
replace marriage = 1 if (relationship2==1) & (relationship3==1) & (relationship5==.c) & (relationship6==.c) & (participation==211211)
replace marriage = 1 if (relationship2==.c) & (relationship3==1) & (relationship5==1) & (relationship6==.c) & (participation==211211) & (n_mar3==n_mar5)

replace marriage = 1 if (relationship2==.c) & (relationship3==1) & (relationship5==1) & (participation==211212) & (n_mar3==n_mar5)
replace marriage = 1 if (relationship2==1) & (relationship3==1) & (relationship5==1) & (participation==211212) & (n_mar3==n_mar5)
replace marriage = 1 if (relationship2==1) & (relationship3==1) & (relationship5==.c) & (participation==211212)

replace marriage = 1 if (relationship2==.c) & (relationship3==1) & (relationship6==1) & (participation==211221) & (n_mar3==n_mar6)
replace marriage = 1 if (relationship2==1) & (relationship3==1) & (relationship6==1) & (participation==211221) & (n_mar3==n_mar6)
replace marriage = 1 if (relationship2==1) & (relationship3==1) & (relationship6==.c) & (participation==211221)

replace marriage = 1 if (relationship2==1) & (relationship3==1) & (participation==211222)

replace marriage = 1 if (relationship2==.c) & (relationship4==1) & (relationship5==1) & (relationship6==1) & (participation==212111)
replace marriage = 1 if (relationship2==.c) & (relationship4==.c) & (relationship5==1) & (relationship6==1) & (participation==212111)
replace marriage = 1 if (relationship2==1) & (relationship4==1) & (relationship5==1) & (relationship6==1) & (participation==212111) & (n_mar2==n_mar4)
replace marriage = 1 if (relationship2==1) & (relationship4==1) & (relationship5==1) & (relationship6==.c) & (participation==212111) & (n_mar2==n_mar4)
replace marriage = 1 if (relationship2==1) & (relationship4==1) & (relationship5==.c) & (relationship6==.c) & (participation==212111) & (n_mar2==n_mar4)
replace marriage = 1 if (relationship2==.c) & (relationship4==1) & (relationship5==1) & (relationship6==.c) & (participation==212111)

replace marriage = 1 if (relationship2==.c) & (relationship4==1) & (relationship5==1) & (participation==212112)
replace marriage = 1 if (relationship2==1) & (relationship4==1) & (relationship5==1) & (participation==212112) & (n_mar2==n_mar4)
replace marriage = 1 if (relationship2==1) & (relationship4==1) & (relationship5==.c) & (participation==212112) & (n_mar2==n_mar4)

replace marriage = 1 if (relationship2==.c) & (relationship4==1) & (relationship6==1) & (participation==212121) & (n_mar4==n_mar6)
replace marriage = 1 if (relationship2==1) & (relationship4==1) & (relationship6==1) & (participation==212121) & (n_mar2==n_mar4) & (n_mar4==n_mar6)
replace marriage = 1 if (relationship2==1) & (relationship4==1) & (relationship6==.c) & (participation==212121) & (n_mar2==n_mar4)

replace marriage = 1 if (relationship2==1) & (relationship4==1) & (participation==212122) & (n_mar2==n_mar4)

replace marriage = 1 if (relationship2==.c) & (relationship5==1) & (relationship6==1) & (participation==212211)
replace marriage = 1 if (relationship2==1) & (relationship5==1) & (relationship6==1) & (participation==212211) & (n_mar2==n_mar5)
replace marriage = 1 if (relationship2==1) & (relationship5==1) & (relationship6==.c) & (participation==212211) & (n_mar2==n_mar5)

replace marriage = 1 if (relationship2==1) & (relationship5==1) & (participation==212212) & (n_mar2==n_mar5)

replace marriage = 1 if (relationship2==1) & (relationship6==1) & (participation==212221) & (n_mar2==n_mar6)

replace marriage = 1 if (relationship3==.c) & (relationship4==1) & (relationship5==1) & (relationship6==1) & (participation==221111)
replace marriage = 1 if (relationship3==.c) & (relationship4==.c) & (relationship5==1) & (relationship6==1) & (participation==221111)
replace marriage = 1 if (relationship3==1) & (relationship4==1) & (relationship5==1) & (relationship6==1) & (participation==221111)
replace marriage = 1 if (relationship3==1) & (relationship4==1) & (relationship5==1) & (relationship6==.c) & (participation==221111)
replace marriage = 1 if (relationship3==1) & (relationship4==1) & (relationship5==.c) & (relationship6==.c) & (participation==221111)
replace marriage = 1 if (relationship3==.c) & (relationship4==1) & (relationship5==1) & (relationship6==.c) & (participation==221111)

replace marriage = 1 if (relationship3==.c) & (relationship4==1) & (relationship5==1) & (participation==221112)
replace marriage = 1 if (relationship3==1) & (relationship4==1) & (relationship5==1) & (participation==221112)
replace marriage = 1 if (relationship3==1) & (relationship4==1) & (relationship5==.c) & (participation==221112)

replace marriage = 1 if (relationship3==.c) & (relationship4==1) & (relationship6==1) & (participation==221121) & (n_mar4==n_mar6)
replace marriage = 1 if (relationship3==1) & (relationship4==1) & (relationship6==1) & (participation==221121) & (n_mar4==n_mar6)
replace marriage = 1 if (relationship3==1) & (relationship4==1) & (relationship6==.c) & (participation==221121)

replace marriage = 1 if (relationship3==1) & (relationship4==1) & (participation==221122)

replace marriage = 1 if (relationship3==.c) & (relationship5==1) & (relationship6==1) & (participation==221211)
replace marriage = 1 if (relationship3==1) & (relationship5==1) & (relationship6==1) & (participation==221211) & (n_mar3==n_mar5)
replace marriage = 1 if (relationship3==1) & (relationship5==1) & (relationship6==.c) & (participation==221211) & (n_mar3==n_mar5)

replace marriage = 1 if (relationship3==1) & (relationship5==1) & (participation==221212) & (n_mar3==n_mar5)

replace marriage = 1 if (relationship3==1) & (relationship6==1) & (participation==221221) & (n_mar3==n_mar6)

replace marriage = 1 if (relationship5==1) & (relationship6==1) & (participation==222211)

* Variable: Constantly being widowed and single

generate constantwid = .c 
replace constantwid = 1 if (relationship1==.c) & (relationship2==4) & (relationship3==4) & (relationship4==4) & (relationship5==4) & (relationship6==4) & (participation==111111)
replace constantwid = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==4) & (relationship4==4) & (relationship5==4) & (relationship6==4) & (participation==111111) 
replace constantwid = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==.c) & (relationship4==4) & (relationship5==4) & (relationship6==4) & (participation==111111) 
replace constantwid = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==.c) & (relationship4==.c) & (relationship5==4) & (relationship6==4) & (participation==111111) 
replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (relationship3==4) & (relationship4==4) & (relationship5==4) & (relationship6==4) & (participation==111111) 
replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (relationship3==4) & (relationship4==4) & (relationship5==4) & (relationship6==.c) & (participation==111111) 
replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (relationship3==4) & (relationship4==4) & (relationship5==.c) & (relationship6==.c) & (participation==111111) 
replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (relationship3==4) & (relationship4==.c) & (relationship5==.c) & (relationship6==.c) & (participation==111111) 
replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (relationship3==.c) & (relationship4==.c) & (relationship5==.c) & (relationship6==.c) & (participation==111111) 
replace constantwid = 1 if (relationship1==.c) & (relationship2==4) & (relationship3==4) & (relationship4==4) & (relationship5==4) & (relationship6==.c) & (participation==111111) 
replace constantwid = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==4) & (relationship4==4) & (relationship5==4) & (relationship6==.c) & (participation==111111) 
replace constantwid = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==.c) & (relationship4==4) & (relationship5==4) & (relationship6==.c) & (participation==111111) 
replace constantwid = 1 if (relationship1==.c) & (relationship2==4) & (relationship3==4) & (relationship4==4) & (relationship5==.c) & (relationship6==.c) & (participation==111111) 
replace constantwid = 1 if (relationship1==.c) & (relationship2==4) & (relationship3==4) & (relationship4==.c) & (relationship5==.c) & (relationship6==.c) & (participation==111111) 

replace constantwid = 1 if (relationship1==.c) & (relationship2==4) & (relationship3==4) & (relationship4==4) & (relationship5==4) & (participation==111112) 
replace constantwid = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==4) & (relationship4==4) & (relationship5==4) & (participation==111112) 
replace constantwid = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==.c) & (relationship4==4) & (relationship5==4) & (participation==111112) 
replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (relationship3==4) & (relationship4==4) & (relationship5==4) & (participation==111112)
replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (relationship3==4) & (relationship4==4) & (relationship5==.c) & (participation==111112)
replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (relationship3==4) & (relationship4==.c) & (relationship5==.c) & (participation==111112)
replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (relationship3==.c) & (relationship4==.c) & (relationship5==.c) & (participation==111112)
replace constantwid = 1 if (relationship1==.c) & (relationship2==4) & (relationship3==4) & (relationship4==4) & (relationship5==.c) & (participation==111112)
replace constantwid = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==4) & (relationship4==4) & (relationship5==.c) & (participation==111112)
replace constantwid = 1 if (relationship1==.c) & (relationship2==4) & (relationship3==4) & (relationship4==.c) & (relationship5==.c) & (participation==111112)

replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (relationship3==4) & (relationship4==4) & (relationship6==.c) & (participation==111121) 
replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (relationship3==4) & (relationship4==.c) & (relationship6==.c) & (participation==111121) 
replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (relationship3==.c) & (relationship4==.c) & (relationship6==.c) & (participation==111121) 
replace constantwid = 1 if (relationship1==.c) & (relationship2==4) & (relationship3==4) & (relationship4==4) & (relationship6==.c) & (participation==111121) 
replace constantwid = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==4) & (relationship4==4) & (relationship6==.c) & (participation==111121) 
replace constantwid = 1 if (relationship1==.c) & (relationship2==4) & (relationship3==4) & (relationship4==.c) & (relationship6==.c) & (participation==111121) 

replace constantwid = 1 if (relationship1==.c) & (relationship2==4) & (relationship3==4) & (relationship4==4) & (participation==111122) 
replace constantwid = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==4) & (relationship4==4) & (participation==111122) 
replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (relationship3==4) & (relationship4==4) & (participation==111122) 
replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (relationship3==4) & (relationship4==.c) & (participation==111122) 
replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (relationship3==.c) & (relationship4==.c) & (participation==111122) 
replace constantwid = 1 if (relationship1==.c) & (relationship2==4) & (relationship3==4) & (relationship4==.c) & (participation==111122) 

replace constantwid = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==.c) & (relationship5==4) & (relationship6==4) & (participation==111211) 
replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (relationship3==4) & (relationship5==.c) & (relationship6==.c) & (participation==111211) 
replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (relationship3==.c) & (relationship5==.c) & (relationship6==.c) & (participation==111211) 
replace constantwid = 1 if (relationship1==.c) & (relationship2==4) & (relationship3==4) & (relationship5==.c) & (relationship6==.c) & (participation==111211) 

replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (relationship3==4) & (relationship5==.c) & (participation==111212) 
replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (relationship3==.c) & (relationship5==.c) & (participation==111212) 
replace constantwid = 1 if (relationship1==.c) & (relationship2==4) & (relationship3==4) & (relationship5==.c) & (participation==111212) 

replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (relationship3==4) & (relationship6==.c) & (participation==111221) 
replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (relationship3==.c) & (relationship6==.c) & (participation==111221) 
replace constantwid = 1 if (relationship1==.c) & (relationship2==4) & (relationship3==4) & (relationship6==.c) & (participation==111221) 

replace constantwid = 1 if (relationship1==.c) & (relationship2==4) & (relationship3==4) & (participation==111222) 
replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (relationship3==4) & (participation==111222) 
replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (relationship3==.c) & (participation==111222) 

replace constantwid = 1 if (relationship1==.c) & (relationship2==.c) & (relationship4==4) & (relationship5==4) & (relationship6==4) & (participation==112111) 
replace constantwid = 1 if (relationship1==.c) & (relationship2==.c) & (relationship4==.c) & (relationship5==4) & (relationship6==4) & (participation==112111) 
replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (relationship4==.c) & (relationship5==.c) & (relationship6==.c) & (participation==112111) 
replace constantwid = 1 if (relationship1==.c) & (relationship2==.c) & (relationship4==4) & (relationship5==4) & (relationship6==.c) & (participation==112111) 

replace constantwid = 1 if (relationship1==.c) & (relationship2==.c) & (relationship4==4) & (relationship5==4) & (participation==112112) 
replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (relationship4==.c) & (relationship5==.c) & (participation==112112)  

replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (relationship4==.c) & (relationship6==.c) & (participation==112121) 

replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (relationship4==.c) & (participation==112122)

replace constantwid = 1 if (relationship1==.c) & (relationship2==.c) & (relationship5==4) & (relationship6==4) & (participation==112211)
replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (relationship5==.c) & (relationship6==.c) & (participation==112211)

replace constantwid = 1 if (relationship1==4) & (relationship2==4) & (participation==112222) 

replace constantwid = 1 if (relationship1==.c) & (relationship3==4) & (relationship4==4) & (relationship5==4) & (relationship6==4) & (participation==121111)
replace constantwid = 1 if (relationship1==.c) & (relationship3==.c) & (relationship4==4) & (relationship5==4) & (relationship6==4) & (participation==121111)
replace constantwid = 1 if (relationship1==.c) & (relationship3==.c) & (relationship4==.c) & (relationship5==4) & (relationship6==4) & (participation==121111)
replace constantwid = 1 if (relationship1==.c) & (relationship3==4) & (relationship4==4) & (relationship5==4) & (relationship6==.c) & (participation==121111)
replace constantwid = 1 if (relationship1==.c) & (relationship3==.c) & (relationship4==4) & (relationship5==4) & (relationship6==.c) & (participation==121111)
replace constantwid = 1 if (relationship1==.c) & (relationship3==4) & (relationship4==4) & (relationship5==.c) & (relationship6==.c) & (participation==121111)

replace constantwid = 1 if (relationship1==.c) & (relationship3==4) & (relationship4==4) & (relationship5==4) & (participation==121112)
replace constantwid = 1 if (relationship1==.c) & (relationship3==.c) & (relationship4==4) & (relationship5==4) & (participation==121112)
replace constantwid = 1 if (relationship1==.c) & (relationship3==4) & (relationship4==4) & (relationship5==.c) & (participation==121112)

replace constantwid = 1 if (relationship1==.c) & (relationship3==4) & (relationship4==4) & (relationship6==.c) & (participation==121121)

replace constantwid = 1 if (relationship1==.c) & (relationship3==4) & (relationship4==4) & (participation==121122) 

replace constantwid = 1 if (relationship1==.c) & (relationship3==.c) & (relationship5==4) & (relationship6==4) & (participation==121211)

replace constantwid = 1 if (relationship1==.c) & (relationship4==4) & (relationship5==4) & (relationship6==4) & (participation==122111)
replace constantwid = 1 if (relationship1==.c) & (relationship4==.c) & (relationship5==4) & (relationship6==4) & (participation==122111)
replace constantwid = 1 if (relationship1==.c) & (relationship4==4) & (relationship5==4) & (relationship6==.c) & (participation==122111)

replace constantwid = 1 if (relationship1==.c) & (relationship4==4) & (relationship5==4) & (participation==122112) 

replace constantwid = 1 if (relationship1==.c) & (relationship5==4) & (relationship6==4) & (participation==122211)

replace constantwid = 1 if (relationship2==.c) & (relationship3==4) & (relationship4==4) & (relationship5==4) & (relationship6==4) & (participation==211111)
replace constantwid = 1 if (relationship2==.c) & (relationship3==.c) & (relationship4==4) & (relationship5==4) & (relationship6==4) & (participation==211111)
replace constantwid = 1 if (relationship2==.c) & (relationship3==.c) & (relationship4==.c) & (relationship5==4) & (relationship6==4) & (participation==211111)
replace constantwid = 1 if (relationship2==4) & (relationship3==4) & (relationship4==4) & (relationship5==4) & (relationship6==4) & (participation==211111)
replace constantwid = 1 if (relationship2==4) & (relationship3==4) & (relationship4==4) & (relationship5==4) & (relationship6==.c) & (participation==211111)
replace constantwid = 1 if (relationship2==4) & (relationship3==4) & (relationship4==4) & (relationship5==.c) & (relationship6==.c) & (participation==211111)
replace constantwid = 1 if (relationship2==4) & (relationship3==4) & (relationship4==.c) & (relationship5==.c) & (relationship6==.c) & (participation==211111)
replace constantwid = 1 if (relationship2==.c) & (relationship3==4) & (relationship4==4) & (relationship5==4) & (relationship6==.c) & (participation==211111)
replace constantwid = 1 if (relationship2==.c) & (relationship3==4) & (relationship4==4) & (relationship5==.c) & (relationship6==.c) & (participation==211111)
replace constantwid = 1 if (relationship2==.c) & (relationship3==.c) & (relationship4==4) & (relationship5==4) & (relationship6==.c) & (participation==211111)

replace constantwid = 1 if (relationship2==.c) & (relationship3==4) & (relationship4==4) & (relationship5==4) & (participation==211112)
replace constantwid = 1 if (relationship2==.c) & (relationship3==.c) & (relationship4==4) & (relationship5==4) & (participation==211112)
replace constantwid = 1 if (relationship2==4) & (relationship3==4) & (relationship4==4) & (relationship5==4) & (participation==211112)
replace constantwid = 1 if (relationship2==4) & (relationship3==4) & (relationship4==4) & (relationship5==.c) & (participation==211112)
replace constantwid = 1 if (relationship2==4) & (relationship3==4) & (relationship4==.c) & (relationship5==.c) & (participation==211112)
replace constantwid = 1 if (relationship2==.c) & (relationship3==4) & (relationship4==4) & (relationship5==.c) & (participation==211112)

replace constantwid = 1 if (relationship2==4) & (relationship3==4) & (relationship4==4) & (relationship6==.c) & (participation==211121)
replace constantwid = 1 if (relationship2==4) & (relationship3==4) & (relationship4==.c) & (relationship6==.c) & (participation==211121)
replace constantwid = 1 if (relationship2==.c) & (relationship3==4) & (relationship4==4) & (relationship6==.c) & (participation==211121)

replace constantwid = 1 if (relationship2==.c) & (relationship3==4) & (relationship4==4) & (participation==211122)
replace constantwid = 1 if (relationship2==4) & (relationship3==4) & (relationship4==4) & (participation==211122)
replace constantwid = 1 if (relationship2==4) & (relationship3==4) & (relationship4==.c) & (participation==211122)

replace constantwid = 1 if (relationship2==.c) & (relationship3==.c) & (relationship5==4) & (relationship6==4) & (participation==211211)
replace constantwid = 1 if (relationship2==4) & (relationship3==4) & (relationship5==.c) & (relationship6==.c) & (participation==211211)

replace constantwid = 1 if (relationship2==4) & (relationship3==4) & (relationship5==.c) & (participation==211212)

replace constantwid = 1 if (relationship2==4) & (relationship3==4) & (relationship6==.c) & (participation==211221)

replace constantwid = 1 if (relationship2==4) & (relationship3==4) & (participation==211222)

replace constantwid = 1 if (relationship2==.c) & (relationship4==4) & (relationship5==4) & (relationship6==4) & (participation==212111)
replace constantwid = 1 if (relationship2==.c) & (relationship4==.c) & (relationship5==4) & (relationship6==4) & (participation==212111)
replace constantwid = 1 if (relationship2==.c) & (relationship4==4) & (relationship5==4) & (relationship6==.c) & (participation==212111)

replace constantwid = 1 if (relationship2==.c) & (relationship4==4) & (relationship5==4) & (participation==212112)

replace constantwid = 1 if (relationship2==.c) & (relationship5==4) & (relationship6==4) & (participation==212211)

replace constantwid = 1 if (relationship3==.c) & (relationship4==4) & (relationship5==4) & (relationship6==4) & (participation==221111)
replace constantwid = 1 if (relationship3==.c) & (relationship4==.c) & (relationship5==4) & (relationship6==4) & (participation==221111)
replace constantwid = 1 if (relationship3==4) & (relationship4==4) & (relationship5==4) & (relationship6==4) & (participation==221111)
replace constantwid = 1 if (relationship3==4) & (relationship4==4) & (relationship5==4) & (relationship6==.c) & (participation==221111)
replace constantwid = 1 if (relationship3==4) & (relationship4==4) & (relationship5==.c) & (relationship6==.c) & (participation==221111)
replace constantwid = 1 if (relationship3==.c) & (relationship4==4) & (relationship5==4) & (relationship6==.c) & (participation==221111)

replace constantwid = 1 if (relationship3==.c) & (relationship4==4) & (relationship5==4) & (participation==221112)
replace constantwid = 1 if (relationship3==4) & (relationship4==4) & (relationship5==4) & (participation==221112)
replace constantwid = 1 if (relationship3==4) & (relationship4==4) & (relationship5==.c) & (participation==221112)

replace constantwid = 1 if (relationship3==4) & (relationship4==4) & (relationship6==.c) & (participation==221121)

replace constantwid = 1 if (relationship3==4) & (relationship4==4) & (participation==221122)

replace constantwid = 1 if (relationship3==.c) & (relationship5==4) & (relationship6==4) & (participation==221211)

replace constantwid = 1 if (relationship5==4) & (relationship6==4) & (participation==222211)


* Variable: Constantly being partnered
generate partner = marriage

foreach X of numlist 5 6 7 {
replace partner = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (relationship6==`X') & (participation==111111)
replace partner = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (relationship6==`X') & (participation==111111) 
replace partner = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==.c) & (relationship4==`X') & (relationship5==`X') & (relationship6==`X') & (participation==111111) 
replace partner = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==.c) & (relationship4==.c) & (relationship5==`X') & (relationship6==`X') & (participation==111111) 
replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (relationship6==`X') & (participation==111111) 
replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (relationship6==.c) & (participation==111111) 
replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==.c) & (relationship6==.c) & (participation==111111) 
replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (relationship4==.c) & (relationship5==.c) & (relationship6==.c) & (participation==111111) 
replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==.c) & (relationship4==.c) & (relationship5==.c) & (relationship6==.c) & (participation==111111) 
replace partner = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (relationship6==.c) & (participation==111111) 
replace partner = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (relationship6==.c) & (participation==111111) 
replace partner = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==.c) & (relationship4==`X') & (relationship5==`X') & (relationship6==.c) & (participation==111111) 
replace partner = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==.c) & (relationship6==.c) & (participation==111111) 
replace partner = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (relationship4==.c) & (relationship5==.c) & (relationship6==.c) & (participation==111111) 

replace partner = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (participation==111112) 
replace partner = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (participation==111112) 
replace partner = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==.c) & (relationship4==`X') & (relationship5==`X') & (participation==111112) 
replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (participation==111112)
replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==.c) & (participation==111112)
replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (relationship4==.c) & (relationship5==.c) & (participation==111112)
replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==.c) & (relationship4==.c) & (relationship5==.c) & (participation==111112)
replace partner = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==.c) & (participation==111112)
replace partner = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==`X') & (relationship4==`X') & (relationship5==.c) & (participation==111112)
replace partner = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (relationship4==.c) & (relationship5==.c) & (participation==111112)

replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship6==.c) & (participation==111121) 
replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (relationship4==.c) & (relationship6==.c) & (participation==111121) 
replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==.c) & (relationship4==.c) & (relationship6==.c) & (participation==111121) 
replace partner = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship6==.c) & (participation==111121) 
replace partner = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==`X') & (relationship4==`X') & (relationship6==.c) & (participation==111121) 
replace partner = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (relationship4==.c) & (relationship6==.c) & (participation==111121) 

replace partner = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (participation==111122) 
replace partner = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==`X') & (relationship4==`X') & (participation==111122) 
replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (participation==111122) 
replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (relationship4==.c) & (participation==111122) 
replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==.c) & (relationship4==.c) & (participation==111122) 
replace partner = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (relationship4==.c) & (participation==111122) 

replace partner = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==.c) & (relationship5==`X') & (relationship6==`X') & (participation==111211) 
replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (relationship5==.c) & (relationship6==.c) & (participation==111211) 
replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==.c) & (relationship5==.c) & (relationship6==.c) & (participation==111211) 
replace partner = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (relationship5==.c) & (relationship6==.c) & (participation==111211) 

replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (relationship5==.c) & (participation==111212) 
replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==.c) & (relationship5==.c) & (participation==111212) 
replace partner = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (relationship5==.c) & (participation==111212) 

replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (relationship6==.c) & (participation==111221) 
replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==.c) & (relationship6==.c) & (participation==111221) 
replace partner = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (relationship6==.c) & (participation==111221) 

replace partner = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (participation==111222) 
replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (participation==111222) 
replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==.c) & (participation==111222) 

replace partner = 1 if (relationship1==.c) & (relationship2==.c) & (relationship4==`X') & (relationship5==`X') & (relationship6==`X') & (participation==112111) 
replace partner = 1 if (relationship1==.c) & (relationship2==.c) & (relationship4==.c) & (relationship5==`X') & (relationship6==`X') & (participation==112111) 
replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (relationship4==.c) & (relationship5==.c) & (relationship6==.c) & (participation==112111) 
replace partner = 1 if (relationship1==.c) & (relationship2==.c) & (relationship4==`X') & (relationship5==`X') & (relationship6==.c) & (participation==112111) 

replace partner = 1 if (relationship1==.c) & (relationship2==.c) & (relationship4==`X') & (relationship5==`X') & (participation==112112) 
replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (relationship4==.c) & (relationship5==.c) & (participation==112112)  

replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (relationship4==.c) & (relationship6==.c) & (participation==112121) 

replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (relationship4==.c) & (participation==112122)

replace partner = 1 if (relationship1==.c) & (relationship2==.c) & (relationship5==`X') & (relationship6==`X') & (participation==112211)
replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (relationship5==.c) & (relationship6==.c) & (participation==112211)

replace partner = 1 if (relationship1==`X') & (relationship2==`X') & (participation==112222) 

replace partner = 1 if (relationship1==.c) & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (relationship6==`X') & (participation==121111)
replace partner = 1 if (relationship1==.c) & (relationship3==.c) & (relationship4==`X') & (relationship5==`X') & (relationship6==`X') & (participation==121111)
replace partner = 1 if (relationship1==.c) & (relationship3==.c) & (relationship4==.c) & (relationship5==`X') & (relationship6==`X') & (participation==121111)
replace partner = 1 if (relationship1==.c) & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (relationship6==.c) & (participation==121111)
replace partner = 1 if (relationship1==.c) & (relationship3==.c) & (relationship4==`X') & (relationship5==`X') & (relationship6==.c) & (participation==121111)
replace partner = 1 if (relationship1==.c) & (relationship3==`X') & (relationship4==`X') & (relationship5==.c) & (relationship6==.c) & (participation==121111)

replace partner = 1 if (relationship1==.c) & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (participation==121112)
replace partner = 1 if (relationship1==.c) & (relationship3==.c) & (relationship4==`X') & (relationship5==`X') & (participation==121112)
replace partner = 1 if (relationship1==.c) & (relationship3==`X') & (relationship4==`X') & (relationship5==.c) & (participation==121112)

replace partner = 1 if (relationship1==.c) & (relationship3==`X') & (relationship4==`X') & (relationship6==.c) & (participation==121121)

replace partner = 1 if (relationship1==.c) & (relationship3==`X') & (relationship4==`X') & (participation==121122) 

replace partner = 1 if (relationship1==.c) & (relationship3==.c) & (relationship5==`X') & (relationship6==`X') & (participation==121211)

replace partner = 1 if (relationship1==.c) & (relationship4==`X') & (relationship5==`X') & (relationship6==`X') & (participation==122111)
replace partner = 1 if (relationship1==.c) & (relationship4==.c) & (relationship5==`X') & (relationship6==`X') & (participation==122111)
replace partner = 1 if (relationship1==.c) & (relationship4==`X') & (relationship5==`X') & (relationship6==.c) & (participation==122111)

replace partner = 1 if (relationship1==.c) & (relationship4==`X') & (relationship5==`X') & (participation==122112) 

replace partner = 1 if (relationship1==.c) & (relationship5==`X') & (relationship6==`X') & (participation==122211)

replace partner = 1 if (relationship2==.c) & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (relationship6==`X') & (participation==211111)
replace partner = 1 if (relationship2==.c) & (relationship3==.c) & (relationship4==`X') & (relationship5==`X') & (relationship6==`X') & (participation==211111)
replace partner = 1 if (relationship2==.c) & (relationship3==.c) & (relationship4==.c) & (relationship5==`X') & (relationship6==`X') & (participation==211111)
replace partner = 1 if (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (relationship6==`X') & (participation==211111)
replace partner = 1 if (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (relationship6==.c) & (participation==211111)
replace partner = 1 if (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==.c) & (relationship6==.c) & (participation==211111)
replace partner = 1 if (relationship2==`X') & (relationship3==`X') & (relationship4==.c) & (relationship5==.c) & (relationship6==.c) & (participation==211111)
replace partner = 1 if (relationship2==.c) & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (relationship6==.c) & (participation==211111)
replace partner = 1 if (relationship2==.c) & (relationship3==`X') & (relationship4==`X') & (relationship5==.c) & (relationship6==.c) & (participation==211111)
replace partner = 1 if (relationship2==.c) & (relationship3==.c) & (relationship4==`X') & (relationship5==`X') & (relationship6==.c) & (participation==211111)

replace partner = 1 if (relationship2==.c) & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (participation==211112)
replace partner = 1 if (relationship2==.c) & (relationship3==.c) & (relationship4==`X') & (relationship5==`X') & (participation==211112)
replace partner = 1 if (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (participation==211112)
replace partner = 1 if (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==.c) & (participation==211112)
replace partner = 1 if (relationship2==`X') & (relationship3==`X') & (relationship4==.c) & (relationship5==.c) & (participation==211112)
replace partner = 1 if (relationship2==.c) & (relationship3==`X') & (relationship4==`X') & (relationship5==.c) & (participation==211112)

replace partner = 1 if (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship6==.c) & (participation==211121)
replace partner = 1 if (relationship2==`X') & (relationship3==`X') & (relationship4==.c) & (relationship6==.c) & (participation==211121)
replace partner = 1 if (relationship2==.c) & (relationship3==`X') & (relationship4==`X') & (relationship6==.c) & (participation==211121)

replace partner = 1 if (relationship2==.c) & (relationship3==`X') & (relationship4==`X') & (participation==211122)
replace partner = 1 if (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (participation==211122)
replace partner = 1 if (relationship2==`X') & (relationship3==`X') & (relationship4==.c) & (participation==211122)

replace partner = 1 if (relationship2==.c) & (relationship3==.c) & (relationship5==`X') & (relationship6==`X') & (participation==211211)
replace partner = 1 if (relationship2==`X') & (relationship3==`X') & (relationship5==.c) & (relationship6==.c) & (participation==211211)

replace partner = 1 if (relationship2==`X') & (relationship3==`X') & (relationship5==.c) & (participation==211212)

replace partner = 1 if (relationship2==`X') & (relationship3==`X') & (relationship6==.c) & (participation==211221)

replace partner = 1 if (relationship2==`X') & (relationship3==`X') & (participation==211222)

replace partner = 1 if (relationship2==.c) & (relationship4==`X') & (relationship5==`X') & (relationship6==`X') & (participation==212111)
replace partner = 1 if (relationship2==.c) & (relationship4==.c) & (relationship5==`X') & (relationship6==`X') & (participation==212111)
replace partner = 1 if (relationship2==.c) & (relationship4==`X') & (relationship5==`X') & (relationship6==.c) & (participation==212111)

replace partner = 1 if (relationship2==.c) & (relationship4==`X') & (relationship5==`X') & (participation==212112)

replace partner = 1 if (relationship2==.c) & (relationship5==`X') & (relationship6==`X') & (participation==212211)

replace partner = 1 if (relationship3==.c) & (relationship4==`X') & (relationship5==`X') & (relationship6==`X') & (participation==221111)
replace partner = 1 if (relationship3==.c) & (relationship4==.c) & (relationship5==`X') & (relationship6==`X') & (participation==221111)
replace partner = 1 if (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (relationship6==`X') & (participation==221111)
replace partner = 1 if (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (relationship6==.c) & (participation==221111)
replace partner = 1 if (relationship3==`X') & (relationship4==`X') & (relationship5==.c) & (relationship6==.c) & (participation==221111)
replace partner = 1 if (relationship3==.c) & (relationship4==`X') & (relationship5==`X') & (relationship6==.c) & (participation==221111)

replace partner = 1 if (relationship3==.c) & (relationship4==`X') & (relationship5==`X') & (participation==221112)
replace partner = 1 if (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (participation==221112)
replace partner = 1 if (relationship3==`X') & (relationship4==`X') & (relationship5==.c) & (participation==221112)

replace partner = 1 if (relationship3==`X') & (relationship4==`X') & (relationship6==.c) & (participation==221121)

replace partner = 1 if (relationship3==`X') & (relationship4==`X') & (participation==221122)

replace partner = 1 if (relationship3==.c) & (relationship5==`X') & (relationship6==`X') & (participation==221211)

replace partner = 1 if (relationship5==`X') & (relationship6==`X') & (participation==222211)
}

* Variable: Constantly being single

generate single = constantwid

foreach X of numlist 2 3 {
replace single = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (relationship6==`X') & (participation==111111)
replace single = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (relationship6==`X') & (participation==111111) 
replace single = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==.c) & (relationship4==`X') & (relationship5==`X') & (relationship6==`X') & (participation==111111) 
replace single = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==.c) & (relationship4==.c) & (relationship5==`X') & (relationship6==`X') & (participation==111111) 
replace single = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (relationship6==`X') & (participation==111111) 
replace single = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (relationship6==.c) & (participation==111111) 
replace single = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==.c) & (relationship6==.c) & (participation==111111) 
replace single = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (relationship4==.c) & (relationship5==.c) & (relationship6==.c) & (participation==111111) 
replace single = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==.c) & (relationship4==.c) & (relationship5==.c) & (relationship6==.c) & (participation==111111) 
replace single = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (relationship6==.c) & (participation==111111) 
replace single = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (relationship6==.c) & (participation==111111) 
replace single = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==.c) & (relationship4==`X') & (relationship5==`X') & (relationship6==.c) & (participation==111111) 
replace single = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==.c) & (relationship6==.c) & (participation==111111) 
replace single = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (relationship4==.c) & (relationship5==.c) & (relationship6==.c) & (participation==111111) 

replace single = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (participation==111112) 
replace single = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (participation==111112) 
replace single = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==.c) & (relationship4==`X') & (relationship5==`X') & (participation==111112) 
replace single = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (participation==111112)
replace single = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==.c) & (participation==111112)
replace single = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (relationship4==.c) & (relationship5==.c) & (participation==111112)
replace single = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==.c) & (relationship4==.c) & (relationship5==.c) & (participation==111112)
replace single = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==.c) & (participation==111112)
replace single = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==`X') & (relationship4==`X') & (relationship5==.c) & (participation==111112)
replace single = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (relationship4==.c) & (relationship5==.c) & (participation==111112)

replace single = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship6==.c) & (participation==111121) 
replace single = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (relationship4==.c) & (relationship6==.c) & (participation==111121) 
replace single = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==.c) & (relationship4==.c) & (relationship6==.c) & (participation==111121) 
replace single = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship6==.c) & (participation==111121) 
replace single = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==`X') & (relationship4==`X') & (relationship6==.c) & (participation==111121) 
replace single = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (relationship4==.c) & (relationship6==.c) & (participation==111121) 

replace single = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (participation==111122) 
replace single = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==`X') & (relationship4==`X') & (participation==111122) 
replace single = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (participation==111122) 
replace single = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (relationship4==.c) & (participation==111122) 
replace single = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==.c) & (relationship4==.c) & (participation==111122) 
replace single = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (relationship4==.c) & (participation==111122) 

replace single = 1 if (relationship1==.c) & (relationship2==.c) & (relationship3==.c) & (relationship5==`X') & (relationship6==`X') & (participation==111211) 
replace single = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (relationship5==.c) & (relationship6==.c) & (participation==111211) 
replace single = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==.c) & (relationship5==.c) & (relationship6==.c) & (participation==111211) 
replace single = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (relationship5==.c) & (relationship6==.c) & (participation==111211) 

replace single = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (relationship5==.c) & (participation==111212) 
replace single = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==.c) & (relationship5==.c) & (participation==111212) 
replace single = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (relationship5==.c) & (participation==111212) 

replace single = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (relationship6==.c) & (participation==111221) 
replace single = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==.c) & (relationship6==.c) & (participation==111221) 
replace single = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (relationship6==.c) & (participation==111221) 

replace single = 1 if (relationship1==.c) & (relationship2==`X') & (relationship3==`X') & (participation==111222) 
replace single = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==`X') & (participation==111222) 
replace single = 1 if (relationship1==`X') & (relationship2==`X') & (relationship3==.c) & (participation==111222) 

replace single = 1 if (relationship1==.c) & (relationship2==.c) & (relationship4==`X') & (relationship5==`X') & (relationship6==`X') & (participation==112111) 
replace single = 1 if (relationship1==.c) & (relationship2==.c) & (relationship4==.c) & (relationship5==`X') & (relationship6==`X') & (participation==112111) 
replace single = 1 if (relationship1==`X') & (relationship2==`X') & (relationship4==.c) & (relationship5==.c) & (relationship6==.c) & (participation==112111) 
replace single = 1 if (relationship1==.c) & (relationship2==.c) & (relationship4==`X') & (relationship5==`X') & (relationship6==.c) & (participation==112111) 

replace single = 1 if (relationship1==.c) & (relationship2==.c) & (relationship4==`X') & (relationship5==`X') & (participation==112112) 
replace single = 1 if (relationship1==`X') & (relationship2==`X') & (relationship4==.c) & (relationship5==.c) & (participation==112112)  

replace single = 1 if (relationship1==`X') & (relationship2==`X') & (relationship4==.c) & (relationship6==.c) & (participation==112121) 

replace single = 1 if (relationship1==`X') & (relationship2==`X') & (relationship4==.c) & (participation==112122)

replace single = 1 if (relationship1==.c) & (relationship2==.c) & (relationship5==`X') & (relationship6==`X') & (participation==112211)
replace single = 1 if (relationship1==`X') & (relationship2==`X') & (relationship5==.c) & (relationship6==.c) & (participation==112211)

replace single = 1 if (relationship1==`X') & (relationship2==`X') & (participation==112222) 

replace single = 1 if (relationship1==.c) & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (relationship6==`X') & (participation==121111)
replace single = 1 if (relationship1==.c) & (relationship3==.c) & (relationship4==`X') & (relationship5==`X') & (relationship6==`X') & (participation==121111)
replace single = 1 if (relationship1==.c) & (relationship3==.c) & (relationship4==.c) & (relationship5==`X') & (relationship6==`X') & (participation==121111)
replace single = 1 if (relationship1==.c) & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (relationship6==.c) & (participation==121111)
replace single = 1 if (relationship1==.c) & (relationship3==.c) & (relationship4==`X') & (relationship5==`X') & (relationship6==.c) & (participation==121111)
replace single = 1 if (relationship1==.c) & (relationship3==`X') & (relationship4==`X') & (relationship5==.c) & (relationship6==.c) & (participation==121111)

replace single = 1 if (relationship1==.c) & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (participation==121112)
replace single = 1 if (relationship1==.c) & (relationship3==.c) & (relationship4==`X') & (relationship5==`X') & (participation==121112)
replace single = 1 if (relationship1==.c) & (relationship3==`X') & (relationship4==`X') & (relationship5==.c) & (participation==121112)

replace single = 1 if (relationship1==.c) & (relationship3==`X') & (relationship4==`X') & (relationship6==.c) & (participation==121121)

replace single = 1 if (relationship1==.c) & (relationship3==`X') & (relationship4==`X') & (participation==121122) 

replace single = 1 if (relationship1==.c) & (relationship3==.c) & (relationship5==`X') & (relationship6==`X') & (participation==121211)

replace single = 1 if (relationship1==.c) & (relationship4==`X') & (relationship5==`X') & (relationship6==`X') & (participation==122111)
replace single = 1 if (relationship1==.c) & (relationship4==.c) & (relationship5==`X') & (relationship6==`X') & (participation==122111)
replace single = 1 if (relationship1==.c) & (relationship4==`X') & (relationship5==`X') & (relationship6==.c) & (participation==122111)

replace single = 1 if (relationship1==.c) & (relationship4==`X') & (relationship5==`X') & (participation==122112) 

replace single = 1 if (relationship1==.c) & (relationship5==`X') & (relationship6==`X') & (participation==122211)

replace single = 1 if (relationship2==.c) & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (relationship6==`X') & (participation==211111)
replace single = 1 if (relationship2==.c) & (relationship3==.c) & (relationship4==`X') & (relationship5==`X') & (relationship6==`X') & (participation==211111)
replace single = 1 if (relationship2==.c) & (relationship3==.c) & (relationship4==.c) & (relationship5==`X') & (relationship6==`X') & (participation==211111)
replace single = 1 if (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (relationship6==`X') & (participation==211111)
replace single = 1 if (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (relationship6==.c) & (participation==211111)
replace single = 1 if (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==.c) & (relationship6==.c) & (participation==211111)
replace single = 1 if (relationship2==`X') & (relationship3==`X') & (relationship4==.c) & (relationship5==.c) & (relationship6==.c) & (participation==211111)
replace single = 1 if (relationship2==.c) & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (relationship6==.c) & (participation==211111)
replace single = 1 if (relationship2==.c) & (relationship3==`X') & (relationship4==`X') & (relationship5==.c) & (relationship6==.c) & (participation==211111)
replace single = 1 if (relationship2==.c) & (relationship3==.c) & (relationship4==`X') & (relationship5==`X') & (relationship6==.c) & (participation==211111)

replace single = 1 if (relationship2==.c) & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (participation==211112)
replace single = 1 if (relationship2==.c) & (relationship3==.c) & (relationship4==`X') & (relationship5==`X') & (participation==211112)
replace single = 1 if (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (participation==211112)
replace single = 1 if (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship5==.c) & (participation==211112)
replace single = 1 if (relationship2==`X') & (relationship3==`X') & (relationship4==.c) & (relationship5==.c) & (participation==211112)
replace single = 1 if (relationship2==.c) & (relationship3==`X') & (relationship4==`X') & (relationship5==.c) & (participation==211112)

replace single = 1 if (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (relationship6==.c) & (participation==211121)
replace single = 1 if (relationship2==`X') & (relationship3==`X') & (relationship4==.c) & (relationship6==.c) & (participation==211121)
replace single = 1 if (relationship2==.c) & (relationship3==`X') & (relationship4==`X') & (relationship6==.c) & (participation==211121)

replace single = 1 if (relationship2==.c) & (relationship3==`X') & (relationship4==`X') & (participation==211122)
replace single = 1 if (relationship2==`X') & (relationship3==`X') & (relationship4==`X') & (participation==211122)
replace single = 1 if (relationship2==`X') & (relationship3==`X') & (relationship4==.c) & (participation==211122)

replace single = 1 if (relationship2==.c) & (relationship3==.c) & (relationship5==`X') & (relationship6==`X') & (participation==211211)
replace single = 1 if (relationship2==`X') & (relationship3==`X') & (relationship5==.c) & (relationship6==.c) & (participation==211211)

replace single = 1 if (relationship2==`X') & (relationship3==`X') & (relationship5==.c) & (participation==211212)

replace single = 1 if (relationship2==`X') & (relationship3==`X') & (relationship6==.c) & (participation==211221)

replace single = 1 if (relationship2==`X') & (relationship3==`X') & (participation==211222)

replace single = 1 if (relationship2==.c) & (relationship4==`X') & (relationship5==`X') & (relationship6==`X') & (participation==212111)
replace single = 1 if (relationship2==.c) & (relationship4==.c) & (relationship5==`X') & (relationship6==`X') & (participation==212111)
replace single = 1 if (relationship2==.c) & (relationship4==`X') & (relationship5==`X') & (relationship6==.c) & (participation==212111)

replace single = 1 if (relationship2==.c) & (relationship4==`X') & (relationship5==`X') & (participation==212112)

replace single = 1 if (relationship2==.c) & (relationship5==`X') & (relationship6==`X') & (participation==212211)

replace single = 1 if (relationship3==.c) & (relationship4==`X') & (relationship5==`X') & (relationship6==`X') & (participation==221111)
replace single = 1 if (relationship3==.c) & (relationship4==.c) & (relationship5==`X') & (relationship6==`X') & (participation==221111)
replace single = 1 if (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (relationship6==`X') & (participation==221111)
replace single = 1 if (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (relationship6==.c) & (participation==221111)
replace single = 1 if (relationship3==`X') & (relationship4==`X') & (relationship5==.c) & (relationship6==.c) & (participation==221111)
replace single = 1 if (relationship3==.c) & (relationship4==`X') & (relationship5==`X') & (relationship6==.c) & (participation==221111)

replace single = 1 if (relationship3==.c) & (relationship4==`X') & (relationship5==`X') & (participation==221112)
replace single = 1 if (relationship3==`X') & (relationship4==`X') & (relationship5==`X') & (participation==221112)
replace single = 1 if (relationship3==`X') & (relationship4==`X') & (relationship5==.c) & (participation==221112)

replace single = 1 if (relationship3==`X') & (relationship4==`X') & (relationship6==.c) & (participation==221121)

replace single = 1 if (relationship3==`X') & (relationship4==`X') & (participation==221122)

replace single = 1 if (relationship3==.c) & (relationship5==`X') & (relationship6==`X') & (participation==221211)

replace single = 1 if (relationship5==`X') & (relationship6==`X') & (participation==222211)

}

save preparation_DEAS.dta, replace

exit

