************************************************************************************************

*** Do partnership transitions affect the individual perception of aging in later life? Findings from the German Ageing Survey and the NRW80+ study
*** Journal of Family Research, 2023
*** Title: 03_JFR_Analysis_Divorce_DEAS
*** Author: Luisa Bischoff

*** Data set: DEAS
* 1996: SUF_DEAS1996_3-0_de_Stata, doi: 10.5156/DEAS.1996.M.004
* 2002: SUF_DEAS2002_3-1_de_Stata, doi: 10.5156/DEAS.2002.M.005
* 2008: SUF_DEAS2008_3-1_de_Stata, doi: 10.5156/DEAS.2008.M.005
* 2011: SUF_DEAS_2011_2-1_de_Stata, doi: 10.5156/DEAS.2011.M.004
* 2014: SUF_DEAS_2014_3-0_de, doi: 10.5156/DEAS.2014.M.005
* 2017: SUF_DEAS_2017_2-0_de, doi: 10.5156/DEAS.2017.M.003
* Meta: SUF_DEAS_Meta_05_2020_de

************************************************************************************************
************************************************************************************************

clear all
capture log close
version 16.1
set more off

*Directories
global outpath 	//  working directory
cd $outpath

************************************************************************************************

use preparation_DEAS.dta, clear

************************************************************************************************
*** Widowhood 
* Relationship status

foreach X of numlist 1/6 {
	generate widowed`X' = .c
}

foreach X of numlist 1/6 {
	replace widowed`X' = 1 if (relationship`X'==4) 
	replace widowed`X' = 0 if (relationship`X'==1) 
}

label define WIDOWED 0 "Married, living together" 1 "Widowed, single" 

foreach X of varlist widowed1-widowed6 {
	label variable `X' "Widowed"
	label values `X' WIDOWED
}

* Transition to widowhood

foreach X of numlist 2/6 {
	generate widowhood`X' = .c	
}

* wave 1 to wave 2
replace widowhood2 = 0 if (widowed1==0) & (widowed2==0) 
replace widowhood2 = 0 if (widowed1==1) & (widowed2==0) 
replace widowhood2 = 0 if (widowed1==1) & (widowed2==1) 
replace widowhood2 = 1 if (widowed1==0) & (widowed2==1) 

* wave 2 to wave 3
replace widowhood3 = 0 if (widowed2==0) & (widowed3==0) 
replace widowhood3 = 0 if (widowed2==1) & (widowed3==0) 
replace widowhood3 = 0 if (widowed2==1) & (widowed3==1) 
replace widowhood3 = 1 if (widowed2==0) & (widowed3==1) 

* wave 3 to wave 4
replace widowhood4 = 0 if (widowed3==0) & (widowed4==0) 
replace widowhood4 = 0 if (widowed3==1) & (widowed4==0) 
replace widowhood4 = 0 if (widowed3==1) & (widowed4==1) 
replace widowhood4 = 1 if (widowed3==0) & (widowed4==1) 

* wave 4 to wave 5
replace widowhood5 = 0 if (widowed4==0) & (widowed5==0) 
replace widowhood5 = 0 if (widowed4==1) & (widowed5==0) 
replace widowhood5 = 0 if (widowed4==1) & (widowed5==1) 
replace widowhood5 = 1 if (widowed4==0) & (widowed5==1) 

* wave 5 to wave 6
replace widowhood6 = 0 if (widowed5==0) & (widowed6==0) 
replace widowhood6 = 0 if (widowed5==1) & (widowed6==0) 
replace widowhood6 = 0 if (widowed5==1) & (widowed6==1) 
replace widowhood6 = 1 if (widowed5==0) & (widowed6==1) 

* Summary
generate widowhood = 0 
replace widowhood = 1 if (widowhood2==1) | (widowhood3==1) | (widowhood4==1) | (widowhood5==1) | (widowhood6==1) 

label define widowhood 0 "widowhood does not occur" 1 "widowhood occurs" 

foreach X of varlist widowhood2-widowhood {
	label variable `X' "Transition to widowhood"
	label values `X' widowhood
}

drop if widowhood==1

************************************************************************************************
*** Divorce/ separation 
* Relationship status

foreach X of numlist 1/6 {
	generate divorced`X' = .c
}

foreach X of numlist 1/6 {
	replace divorced`X' = 1 if ((relationship`X'==2) | (relationship`X'==3)) & (widowhood!=1)  
	replace divorced`X' = 0 if (relationship`X'==1) & (widowhood!=1)
}

label define DIVORCED 0 "Married, living together" 1 "Divorced, single" 

foreach X of varlist divorced1-divorced6 {
	label variable `X' "Divorced"
	label values `X' DIVORCED
}


foreach X of numlist 1/6 {
	generate separated`X' = .c
}

foreach X of numlist 1/6 {
	replace separated`X' = 1 if ((relationship`X'==2) | (relationship`X'==3) | (relationship`X'==4)) & (widowhood!=1)  
	replace separated`X' = 0 if ((relationship`X'==5) | (relationship`X'==6) | (relationship`X'==7)) & (widowhood!=1) 
}

label define SEPARATED 0 "Partnered" 1 "Separated, single" 

foreach X of varlist separated1-separated6 {
	label variable `X' "Separated "
	label values `X' SEPARATED
}


foreach X of numlist 1/6 {
	generate separation`X' = .c
}

foreach X of numlist 1/6 {
	replace separation`X' = 1 if (divorced`X'==1) | (separated`X'==1)
	replace separation`X' = 0 if (divorced`X'==0) | (separated`X'==0)
}

label define SEPARATION 0 "Partnered" 1 "Divorced or separated, single" 

foreach X of varlist separation1-separation6 {
	label variable `X' "Divorced or Separated "
	label values `X' SEPARATION
}


* Transition of divorce or separation

foreach X of numlist 2/6 {
	generate divorce`X' = .c	
}

* wave 1 to wave 2
replace divorce2 = 0 if (separation1==0) & (separation2==0) 
replace divorce2 = 0 if (separation1==1) & (separation2==0) 
replace divorce2 = 0 if (separation1==1) & (separation2==1) 
replace divorce2 = 1 if (separation1==0) & (separation2==1) 

* wave 2 to wave 3
replace divorce3 = 0 if (separation2==0) & (separation3==0) 
replace divorce3 = 0 if (separation2==1) & (separation3==0) 
replace divorce3 = 0 if (separation2==1) & (separation3==1) 
replace divorce3 = 1 if (separation2==0) & (separation3==1) 

* wave 3 to wave 4
replace divorce4 = 0 if (separation3==0) & (separation4==0) 
replace divorce4 = 0 if (separation3==1) & (separation4==0) 
replace divorce4 = 0 if (separation3==1) & (separation4==1) 
replace divorce4 = 1 if (separation3==0) & (separation4==1) 

* wave 4 to wave 5
replace divorce5 = 0 if (separation4==0) & (separation5==0) 
replace divorce5 = 0 if (separation4==1) & (separation5==0) 
replace divorce5 = 0 if (separation4==1) & (separation5==1) 
replace divorce5 = 1 if (separation4==0) & (separation5==1) 

* wave 5 to wave 6
replace divorce6 = 0 if (separation5==0) & (separation6==0) 
replace divorce6 = 0 if (separation5==1) & (separation6==0) 
replace divorce6 = 0 if (separation5==1) & (separation6==1) 
replace divorce6 = 1 if (separation5==0) & (separation6==1) 

* Summary
generate divorce = 0 
replace divorce = 1 if (divorce2==1) | (divorce3==1) | (divorce4==1) | (divorce5==1) | (divorce6==1) 

label define DIVORCE 0 "divorce does not occur" 1 "divorce occurs" 

foreach X of varlist divorce2-divorce {
	label variable `X' "Transition of divorce or separation"
	label values `X' DIVORCE
}

recode separation1-separation6 (.c=0)

************************************************************************************************
*** Sampling
keep if (partner==1) | (single==1) | (divorce==1) 
/// Keeping respondents who are constantly partnered, constantly single, or experience divorce/separation 

************************************************************************************************
*** Preparing longitudinal data
keep fallnum gender education migrat health1 health2 health3 health4 health5 health6 age1 age2 age3 age4 age5 age6 pa1 pa2 pa3 pa4 pa5 pa6 widowed1 separation1 separation2 separation3 separation4 separation5 separation6 adaption1 adaption2 adaption3 adaption4 adaption5 adaption6 vitality1 vitality2 vitality3 vitality4 vitality5 vitality6 freedom1 freedom2 freedom3 freedom4 freedom5 freedom6 needs1 needs2 needs3 needs4 needs5 needs6 cognitive1 cognitive2 cognitive3 cognitive4 cognitive5 cognitive6 dependency1 dependency2 dependency3 dependency4 dependency5 dependency6 serenity1 serenity2 serenity3 serenity4 serenity5 serenity6 grandparents1 grandparents2 grandparents3 grandparents4 grandparents5 grandparents6 network1 network2 network3 network4 network5 network6 partner single divorce n_obs
/// Keep relevant variables 

reshape long separation age pa freedom needs adaption cognitive dependency vitality serenity health grandparents network, i(fallnum) j(wave)
/// Long format

* Interactional term: Gender + Divorce/separation
generate genderdiv = gender*separation

*** Generating panel data
xtset fallnum wave

*** Preparing variables for regression
* Independent variables
egen b_separation=mean(separation), by(fallnum)
gen w_separation=separation-b_separation

egen b_gender=mean(gender), by(fallnum)

egen b_genderdiv=mean(genderdiv), by(fallnum)
gen w_genderdiv=genderdiv-b_genderdiv

* Control variables
egen b_age=mean(age), by(fallnum)
gen w_age=age-b_age

egen b_education=mean(education), by(fallnum)

egen b_migrat=mean(migrat), by(fallnum)

egen b_health=mean(health), by(fallnum)
gen w_health=health-b_health

egen b_grandparents=mean(grandparents), by(fallnum)
gen w_grandparents=grandparents-b_grandparents

egen b_network=mean(network), by(fallnum)
gen w_network=network-b_network

*** Main analysis: Hybrid, linear panel regression

* The following code was used to create Table 4a
* Model a: Index PA 
xtreg pa  b_separation w_separation, re
outreg2 using Table_4a .xls, replace ctitle(Model 1a) dec(2)
xtreg pa  b_separation b_gender w_separation, re
outreg2 using Table_4a .xls, append ctitle(Model 2a) dec(2)
xtreg pa  b_separation b_gender b_genderdiv w_separation w_genderdiv, re
outreg2 using Table_4a .xls, append ctitle(Model 3a) dec(2)
xtreg pa  b_separation b_gender b_genderdiv b_age b_education b_migrat b_health b_grandparents b_network w_separation w_genderdiv w_age w_health w_grandparents w_network, re
outreg2 using Table_4a .xls, append ctitle(Model 4a) dec(2)

* Model b: Freedom
xtreg freedom b_separation w_separation, re
outreg2 using Table_4a.xls, append ctitle(Model 1b) dec(2)
xtreg freedom b_separation b_gender w_separation, re
outreg2 using Table_4a.xls, append ctitle(Model 2b) dec(2)
xtreg freedom b_separation b_gender b_genderdiv w_separation w_genderdiv, re
outreg2 using Table_4a.xls, append ctitle(Model 3b) dec(2)
xtreg freedom b_separation b_gender b_genderdiv b_age b_education b_migrat b_health b_grandparents b_network w_separation w_genderdiv w_age w_health w_grandparents w_network, re
outreg2 using Table_4a.xls, append ctitle(Model 4b) dec(2)

* Model c: Needs
xtreg needs  b_separation w_separation, re
outreg2 using Table_4a .xls, append ctitle(Model 1c) dec(2)
xtreg needs  b_separation b_gender w_separation, re
outreg2 using Table_4a .xls, append ctitle(Model 2c) dec(2)
xtreg needs  b_separation b_gender b_genderdiv w_separation w_genderdiv, re
outreg2 using Table_4a .xls, append ctitle(Model 3c) dec(2)
xtreg needs  b_separation b_gender b_genderdiv b_age b_education b_migrat b_health b_grandparents b_network w_separation w_genderdiv w_age w_health w_grandparents w_network, re
outreg2 using Table_4a .xls, append ctitle(Model 4c) dec(2)

* Model d: Adaption
xtreg adaption b_separation w_separation, re
outreg2 using Table_4a.xls, append ctitle(Model 1d) dec(2)
xtreg adaption b_separation b_gender w_separation, re
outreg2 using Table_4a.xls, append ctitle(Model 2d) dec(2)
xtreg adaption b_separation b_gender b_genderdiv w_separation w_genderdiv, re
outreg2 using Table_4a.xls, append ctitle(Model 3d) dec(2)
xtreg adaption b_separation b_gender b_genderdiv b_age b_education b_migrat b_health b_grandparents b_network w_separation w_genderdiv w_age w_health w_grandparents w_network, re
outreg2 using Table_4a.xls, append ctitle(Model 4d) dec(2)

* The following code was used to create Table 4b
* Model e: Cognitive capacity
xtreg cognitive b_separation w_separation, re
outreg2 using Table_4b.xls, replace ctitle(Model 1e) dec(2)
xtreg cognitive b_separation b_gender w_separation, re
outreg2 using Table_4b.xls, append ctitle(Model 2e) dec(2)
xtreg cognitive b_separation b_gender b_genderdiv w_separation w_genderdiv, re
outreg2 using Table_4b.xls, append ctitle(Model 3e) dec(2)
xtreg cognitive b_separation b_gender b_genderdiv b_age b_education b_migrat b_health b_grandparents b_network w_separation w_genderdiv w_age w_health w_grandparents w_network, re
outreg2 using Table_4b.xls, append ctitle(Model 4e) dec(2)

* Model f: Dependency
xtreg dependency b_separation w_separation, re
outreg2 using Table_4b.xls, append ctitle(Model 1f) dec(2)
xtreg dependency b_separation b_gender w_separation, re
outreg2 using Table_4b.xls, append ctitle(Model 2f) dec(2)
xtreg dependency b_separation b_gender b_genderdiv w_separation w_genderdiv, re
outreg2 using Table_4b.xls, append ctitle(Model 3f) dec(2)
xtreg dependency b_separation b_gender b_genderdiv b_age b_education b_migrat b_health b_grandparents b_network w_separation w_genderdiv w_age w_health w_grandparents w_network, re
outreg2 using Table_4b.xls, append ctitle(Model 4f) dec(2)

* Model g: Vitality
xtreg vitality b_separation w_separation, re
outreg2 using Table_4b.xls, append ctitle(Model 1g) dec(2)
xtreg vitality b_separation b_gender w_separation, re
outreg2 using Table_4b.xls, append ctitle(Model 2g) dec(2)
xtreg vitality b_separation b_gender b_genderdiv w_separation w_genderdiv, re
outreg2 using Table_4b.xls, append ctitle(Model 3g) dec(2)
xtreg vitality b_separation b_gender b_genderdiv b_age b_education b_migrat b_health b_grandparents b_network w_separation w_genderdiv w_age w_health w_grandparents w_network, re
outreg2 using Table_4b.xls, append ctitle(Model 4g) dec(2)

* Model h: Serenity
xtreg serenity b_separation w_separation, re
outreg2 using Table_4b.xls, append ctitle(Model 1h) dec(2)
xtreg serenity b_separation b_gender w_separation, re
outreg2 using Table_4b.xls, append ctitle(Model 2h) dec(2)
xtreg serenity b_separation b_gender b_genderdiv w_separation w_genderdiv, re
outreg2 using Table_4b.xls, append ctitle(Model 3h) dec(2)
xtreg serenity b_separation b_gender b_genderdiv b_age b_education b_migrat b_health b_grandparents b_network w_separation w_genderdiv w_age w_health w_grandparents w_network, re
outreg2 using Table_4b.xls, append ctitle(Model 4h) dec(2)


*** Robustness-check: Fixed-effects panel regression

* The following code was used to create Table A.4a
* Model a: Index PA 
xtreg pa  w_separation, fe
outreg2 using Table_A4a.xls, replace ctitle(Model 1a) dec(2)
xtreg pa  w_separation w_genderdiv, fe
outreg2 using Table_A4a.xls, append ctitle(Model 2a) dec(2)
xtreg pa  w_separation w_genderdiv w_age w_health w_grandparents w_network, fe
outreg2 using Table_A4a.xls, append ctitle(Model 3a) dec(2)

* Model b: Freedom
xtreg freedom w_separation, fe
outreg2 using Table_A4a.xls, append ctitle(Model 1b) dec(2)
xtreg freedom w_separation w_genderdiv, fe
outreg2 using Table_A4a.xls, append ctitle(Model 2b) dec(2)
xtreg freedom w_separation w_genderdiv w_age w_health w_grandparents w_network, fe
outreg2 using Table_A4a.xls, append ctitle(Model 3b) dec(2)

* Model c: Needs
xtreg needs w_separation, fe
outreg2 using Table_A4a.xls, append ctitle(Model 1c) dec(2)
xtreg needs w_separation w_genderdiv, fe
outreg2 using Table_A4a.xls, append ctitle(Model 2c) dec(2)
xtreg needs w_separation w_genderdiv w_age w_health w_grandparents w_network, fe
outreg2 using Table_A4a.xls, append ctitle(Model 3c) dec(2)

* Model d: Adaption
xtreg adaption w_separation, fe
outreg2 using Table_A4a.xls, append ctitle(Model 1d) dec(2)
xtreg adaption w_separation w_genderdiv, fe
outreg2 using Table_A4a.xls, append ctitle(Model 2d) dec(2)
xtreg adaption w_separation w_genderdiv w_age w_health w_grandparents w_network, fe
outreg2 using Table_A4a.xls, append ctitle(Model 3d) dec(2)

* The following code was used to create Table A.4b
* Model e: Cognitive capacity
xtreg cognitive w_separation, fe
outreg2 using Table_A4b.xls, replace ctitle(Model 1e) dec(2)
xtreg cognitive w_separation w_genderdiv, fe
outreg2 using Table_A4b.xls, append ctitle(Model 2e) dec(2)
xtreg cognitive w_separation w_genderdiv w_age w_health w_grandparents w_network, fe
outreg2 using Table_A4b.xls, append ctitle(Model 3e) dec(2)

* Model f: Dependency
xtreg dependency w_separation, fe
outreg2 using Table_A4b.xls, append ctitle(Model 1f) dec(2)
xtreg dependency w_separation w_genderdiv, fe
outreg2 using Table_A4b.xls, append ctitle(Model 2f) dec(2)
xtreg dependency w_separation w_genderdiv w_age w_health w_grandparents w_network, fe
outreg2 using Table_A4b.xls, append ctitle(Model 3f) dec(2)

* Model g: Vitality
xtreg vitality w_separation, fe
outreg2 using Table_A4b.xls, append ctitle(Model 1g) dec(2)
xtreg vitality w_separation w_genderdiv, fe
outreg2 using Table_A4b.xls, append ctitle(Model 2g) dec(2)
xtreg vitality w_separation w_genderdiv w_age w_health w_grandparents w_network, fe
outreg2 using Table_A4b.xls, append ctitle(Model 3g) dec(2)

* Model h: Serenity
xtreg serenity w_separation, fe
outreg2 using Table_A4b.xls, append ctitle(Model 1h) dec(2)
xtreg serenity w_separation w_genderdiv, fe
outreg2 using Table_A4b.xls, append ctitle(Model 2h) dec(2)
xtreg serenity w_separation w_genderdiv w_age w_health w_grandparents w_network, fe
outreg2 using Table_A4b.xls, append ctitle(Model 3h) dec(2)


exit
