************************************************************************************************

*** Do partnership transitions affect the individual perception of aging in later life? Findings from the German Ageing Survey and the NRW80+ study
*** Journal of Family Research, 2023
*** Title: 04_JFR_Analysis_Repartnering_DEAS
*** Author: Luisa Bischoff

*** Data set: DEAS
* 1996: SUF_DEAS1996_3-0_de_Stata, doi: 10.5156/DEAS.1996.M.004
* 2002: SUF_DEAS2002_3-1_de_Stata, doi: 10.5156/DEAS.2002.M.005
* 2008: SUF_DEAS2008_3-1_de_Stata, doi: 10.5156/DEAS.2008.M.005
* 2011: SUF_DEAS_2011_2-1_de_Stata, doi: 10.5156/DEAS.2011.M.004
* 2014: SUF_DEAS_2014_3-0_de, doi: 10.5156/DEAS.2014.M.005
* 2017: SUF_DEAS_2017_2-0_de, doi: 10.5156/DEAS.2017.M.003
* Meta: SUF_DEAS_Meta_05_2020_de

************************************************************************************************
************************************************************************************************

clear all
capture log close
version 16.1
set more off

*Directories
global outpath 	//  working directory
cd $outpath

************************************************************************************************

use preparation_DEAS.dta, clear

************************************************************************************************
*** Repartnering
* Relationship status

foreach X of numlist 1/6 {
	generate repartner`X' = .c
}

foreach X of numlist 1/6 {
	replace repartner`X' = 0 if (relationship`X'==2) | (relationship`X'==3) | (relationship`X'==4) 
	replace repartner`X' = 1 if (relationship`X'==5) | (relationship`X'==6) | (relationship`X'==7)
}

label define REPARTNER 0 "Single" 1 "Living in non-marital partnership" 

foreach X of varlist repartner1-repartner6 {
	label variable `X' "Repartner"
	label values `X' REPARTNER
}

* Transition to new partnership

foreach X of numlist 2/6 {
	generate repartnering`X' = .c	
}

* wave 1 to wave 2
replace repartnering2 = 0 if (repartner1==0) & (repartner2==0) 
replace repartnering2 = 0 if (repartner1==1) & (repartner2==0) 
replace repartnering2 = 0 if (repartner1==1) & (repartner2==1) 
replace repartnering2 = 1 if (repartner1==0) & (repartner2==1) 

* wave 2 to wave 3
replace repartnering3 = 0 if (repartner2==0) & (repartner3==0) 
replace repartnering3 = 0 if (repartner2==1) & (repartner3==0) 
replace repartnering3 = 0 if (repartner2==1) & (repartner3==1) 
replace repartnering3 = 1 if (repartner2==0) & (repartner3==1) 

* wave 3 to wave 4
replace repartnering4 = 0 if (repartner3==0) & (repartner4==0) 
replace repartnering4 = 0 if (repartner3==1) & (repartner4==0) 
replace repartnering4 = 0 if (repartner3==1) & (repartner4==1) 
replace repartnering4 = 1 if (repartner3==0) & (repartner4==1) 

* wave 4 to wave 5
replace repartnering5 = 0 if (repartner4==0) & (repartner5==0) 
replace repartnering5 = 0 if (repartner4==1) & (repartner5==0) 
replace repartnering5 = 0 if (repartner4==1) & (repartner5==1) 
replace repartnering5 = 1 if (repartner4==0) & (repartner5==1) 

* wave 5 to wave 6
replace repartnering6 = 0 if (repartner5==0) & (repartner6==0) 
replace repartnering6 = 0 if (repartner5==1) & (repartner6==0) 
replace repartnering6 = 0 if (repartner5==1) & (repartner6==1) 
replace repartnering6 = 1 if (repartner5==0) & (repartner6==1) 

* Summary
generate repartnering = 0 
replace repartnering = 1 if (repartnering2==1) | (repartnering3==1) | (repartnering4==1) | (repartnering5==1) | (repartnering6==1) 

label define repartnering 0 "repartnering does not occur" 1 "repartnering occurs" 

foreach X of varlist repartnering2-repartnering {
	label variable `X' "Transition to new partnership"
	label values `X' repartnering
}

recode repartner1-repartner6 (.c=0)

************************************************************************************************
*** Sampling
keep if (partner==1) | (single==1) | (repartnering==1)
/// Keeping respondents who are constantly partnered, constantly single, or experience repartnering 

************************************************************************************************
*** Preparing longitudinal data
keep fallnum gender education migrat health1 health2 health3 health4 health5 health6 age1 age2 age3 age4 age5 age6 pa1 pa2 pa3 pa4 pa5 pa6 widowed1 repartner1 repartner2 repartner3 repartner4 repartner5 repartner6 adaption1 adaption2 adaption3 adaption4 adaption5 adaption6 vitality1 vitality2 vitality3 vitality4 vitality5 vitality6 freedom1 freedom2 freedom3 freedom4 freedom5 freedom6 needs1 needs2 needs3 needs4 needs5 needs6 cognitive1 cognitive2 cognitive3 cognitive4 cognitive5 cognitive6 dependency1 dependency2 dependency3 dependency4 dependency5 dependency6 serenity1 serenity2 serenity3 serenity4 serenity5 serenity6 grandparents1 grandparents2 grandparents3 grandparents4 grandparents5 grandparents6 network1 network2 network3 network4 network5 network6 partner single repartnering n_obs
/// Keep relevant variables 

reshape long repartner age pa freedom needs adaption cognitive dependency vitality serenity health grandparents network, i(fallnum) j(wave)
/// Long format

* Interactional term: Gender + Repartnering
generate genderrep = gender*repartner

*** Generating panel data
xtset fallnum wave

*** Preparing variables for regression
*Independent variables
egen b_repartner=mean(repartner), by(fallnum)
gen w_repartner=repartner-b_repartner

egen b_gender=mean(gender), by(fallnum)

egen b_genderrep=mean(genderrep), by(fallnum)
gen w_genderrep=genderrep-b_genderrep

* Control variables
egen b_age=mean(age), by(fallnum)
gen w_age=age-b_age

egen b_education=mean(education), by(fallnum)

egen b_migrat=mean(migrat), by(fallnum)

egen b_health=mean(health), by(fallnum)
gen w_health=health-b_health

egen b_grandparents=mean(grandparents), by(fallnum)
gen w_grandparents=grandparents-b_grandparents

egen b_network=mean(network), by(fallnum)
gen w_network=network-b_network

*** Main analysis: Hybrid, linear panel regression

* The following code was used to create Table 5a
* Model a: Index PA 
xtreg pa  b_repartner w_repartner, re
outreg2 using Table_5a .xls, replace ctitle(Model 1a) dec(2)
xtreg pa  b_repartner b_gender w_repartner, re
outreg2 using Table_5a .xls, append ctitle(Model 2a) dec(2)
xtreg pa  b_repartner b_gender b_genderrep w_repartner w_genderrep, re
outreg2 using Table_5a .xls, append ctitle(Model 3a) dec(2)
xtreg pa  b_repartner b_gender b_genderrep b_age b_education b_migrat b_health b_grandparents b_network w_repartner w_genderrep w_age w_health w_grandparents w_network, re
outreg2 using Table_5a .xls, append ctitle(Model 4a) dec(2)

* Model b: Freedom
xtreg freedom b_repartner w_repartner, re
outreg2 using Table_5a.xls, append ctitle(Model 1b) dec(2)
xtreg freedom b_repartner b_gender w_repartner, re
outreg2 using Table_5a.xls, append ctitle(Model 2b) dec(2)
xtreg freedom b_repartner b_gender b_genderrep w_repartner w_genderrep, re
outreg2 using Table_5a.xls, append ctitle(Model 3b) dec(2)
xtreg freedom b_repartner b_gender b_genderrep b_age b_education b_migrat b_health b_grandparents b_network w_repartner w_genderrep w_age w_health w_grandparents w_network, re
outreg2 using Table_5a.xls, append ctitle(Model 4b) dec(2)

* Model c: Needs
xtreg needs  b_repartner w_repartner, re
outreg2 using Table_5a .xls, append ctitle(Model 1c) dec(2)
xtreg needs  b_repartner b_gender w_repartner, re
outreg2 using Table_5a .xls, append ctitle(Model 2c) dec(2)
xtreg needs  b_repartner b_gender b_genderrep w_repartner w_genderrep, re
outreg2 using Table_5a .xls, append ctitle(Model 3c) dec(2)
xtreg needs  b_repartner b_gender b_genderrep b_age b_education b_migrat b_health b_grandparents b_network w_repartner w_genderrep w_age w_health w_grandparents w_network, re
outreg2 using Table_5a .xls, append ctitle(Model 4c) dec(2)

* Model d: Adaption
xtreg adaption b_repartner w_repartner, re
outreg2 using Table_5a.xls, append ctitle(Model 1d) dec(2)
xtreg adaption b_repartner b_gender w_repartner, re
outreg2 using Table_5a.xls, append ctitle(Model 2d) dec(2)
xtreg adaption b_repartner b_gender b_genderrep w_repartner w_genderrep, re
outreg2 using Table_5a.xls, append ctitle(Model 3d) dec(2)
xtreg adaption b_repartner b_gender b_genderrep b_age b_education b_migrat b_health b_grandparents b_network w_repartner w_genderrep w_age w_health w_grandparents w_network, re
outreg2 using Table_5a.xls, append ctitle(Model 4d) dec(2)

* The following code was used to create Table 5b
* Model e: Cognitive capacity
xtreg cognitive b_repartner w_repartner, re
outreg2 using Table_5b.xls, replace ctitle(Model 1e) dec(2)
xtreg cognitive b_repartner b_gender w_repartner, re
outreg2 using Table_5b.xls, append ctitle(Model 2e) dec(2)
xtreg cognitive b_repartner b_gender b_genderrep w_repartner w_genderrep, re
outreg2 using Table_5b.xls, append ctitle(Model 3e) dec(2)
xtreg cognitive b_repartner b_gender b_genderrep b_age b_education b_migrat b_health b_grandparents b_network w_repartner w_genderrep w_age w_health w_grandparents w_network, re
outreg2 using Table_5b.xls, append ctitle(Model 4e) dec(2)

* Model f: Dependency
xtreg dependency b_repartner w_repartner, re
outreg2 using Table_5b.xls, append ctitle(Model 1f) dec(2)
xtreg dependency b_repartner b_gender w_repartner, re
outreg2 using Table_5b.xls, append ctitle(Model 2f) dec(2)
xtreg dependency b_repartner b_gender b_genderrep w_repartner w_genderrep, re
outreg2 using Table_5b.xls, append ctitle(Model 3f) dec(2)
xtreg dependency b_repartner b_gender b_genderrep b_age b_education b_migrat b_health b_grandparents b_network w_repartner w_genderrep w_age w_health w_grandparents w_network, re
outreg2 using Table_5b.xls, append ctitle(Model 4f) dec(2)

* Model g: Vitality
xtreg vitality b_repartner w_repartner, re
outreg2 using Table_5b.xls, append ctitle(Model 1g) dec(2)
xtreg vitality b_repartner b_gender w_repartner, re
outreg2 using Table_5b.xls, append ctitle(Model 2g) dec(2)
xtreg vitality b_repartner b_gender b_genderrep w_repartner w_genderrep, re
outreg2 using Table_5b.xls, append ctitle(Model 3g) dec(2)
xtreg vitality b_repartner b_gender b_genderrep b_age b_education b_migrat b_health b_grandparents b_network w_repartner w_genderrep w_age w_health w_grandparents w_network, re
outreg2 using Table_5b.xls, append ctitle(Model 4g) dec(2)

* Model h: Serenity
xtreg serenity b_repartner w_repartner, re
outreg2 using Table_5b.xls, append ctitle(Model 1h) dec(2)
xtreg serenity b_repartner b_gender w_repartner, re
outreg2 using Table_5b.xls, append ctitle(Model 2h) dec(2)
xtreg serenity b_repartner b_gender b_genderrep w_repartner w_genderrep, re
outreg2 using Table_5b.xls, append ctitle(Model 3h) dec(2)
xtreg serenity b_repartner b_gender b_genderrep b_age b_education b_migrat b_health b_grandparents b_network w_repartner w_genderrep w_age w_health w_grandparents w_network, re
outreg2 using Table_5b.xls, append ctitle(Model 4h) dec(2)


*** Robustness-check: Fixed-effects panel regression

* The following code was used to create Table A.5a
* Model a: Index PA 
xtreg pa  w_repartner, fe
outreg2 using Table_A5a.xls, replace ctitle(Model 1a) dec(2)
xtreg pa  w_repartner w_genderrep, fe
outreg2 using Table_A5a.xls, append ctitle(Model 2a) dec(2)
xtreg pa  w_repartner w_genderrep w_age w_health w_grandparents w_network, fe
outreg2 using Table_A5a.xls, append ctitle(Model 3a) dec(2)

* Model b: Freedom
xtreg freedom w_repartner, fe
outreg2 using Table_A5a.xls, append ctitle(Model 1b) dec(2)
xtreg freedom w_repartner w_genderrep, fe
outreg2 using Table_A5a.xls, append ctitle(Model 2b) dec(2)
xtreg freedom w_repartner w_genderrep w_age w_health w_grandparents w_network, fe
outreg2 using Table_A5a.xls, append ctitle(Model 3b) dec(2)

* Model c: Needs
xtreg needs w_repartner, fe
outreg2 using Table_A5a.xls, append ctitle(Model 1c) dec(2)
xtreg needs w_repartner w_genderrep, fe
outreg2 using Table_A5a.xls, append ctitle(Model 2c) dec(2)
xtreg needs w_repartner w_genderrep w_age w_health w_grandparents w_network, fe
outreg2 using Table_A5a.xls, append ctitle(Model 3c) dec(2)

* Model d: Adaption
xtreg adaption w_repartner, fe
outreg2 using Table_A5a.xls, append ctitle(Model 1d) dec(2)
xtreg adaption w_repartner w_genderrep, fe
outreg2 using Table_A5a.xls, append ctitle(Model 2d) dec(2)
xtreg adaption w_repartner w_genderrep w_age w_health w_grandparents w_network, fe
outreg2 using Table_A5a.xls, append ctitle(Model 3d) dec(2)

* The following code was used to create Table A.5b
* Model e: Cognitive capacity
xtreg cognitive w_repartner, fe
outreg2 using Table_A5b.xls, replace ctitle(Model 1e) dec(2)
xtreg cognitive w_repartner w_genderrep, fe
outreg2 using Table_A5b.xls, append ctitle(Model 2e) dec(2)
xtreg cognitive w_repartner w_genderrep w_age w_health w_grandparents w_network, fe
outreg2 using Table_A5b.xls, append ctitle(Model 3e) dec(2)

* Model f: Dependency
xtreg dependency w_repartner, fe
outreg2 using Table_A5b.xls, append ctitle(Model 1f) dec(2)
xtreg dependency w_repartner w_genderrep, fe
outreg2 using Table_A5b.xls, append ctitle(Model 2f) dec(2)
xtreg dependency w_repartner w_genderrep w_age w_health w_grandparents w_network, fe
outreg2 using Table_A5b.xls, append ctitle(Model 3f) dec(2)

* Model g: Vitality
xtreg vitality w_repartner, fe
outreg2 using Table_A5b.xls, append ctitle(Model 1g) dec(2)
xtreg vitality w_repartner w_genderrep, fe
outreg2 using Table_A5b.xls, append ctitle(Model 2g) dec(2)
xtreg vitality w_repartner w_genderrep w_age w_health w_grandparents w_network, fe
outreg2 using Table_A5b.xls, append ctitle(Model 3g) dec(2)

* Model h: Serenity
xtreg serenity w_repartner, fe
outreg2 using Table_A5b.xls, append ctitle(Model 1h) dec(2)
xtreg serenity w_repartner w_genderrep, fe
outreg2 using Table_A5b.xls, append ctitle(Model 2h) dec(2)
xtreg serenity w_repartner w_genderrep w_age w_health w_grandparents w_network, fe
outreg2 using Table_A5b.xls, append ctitle(Model 3h) dec(2)


exit
