********************************************************************************
********************************************************************************
*Do partnership transitions affect the individual perception of aging in later life? Findings from the German Ageing Survey and the NRW80+ study
*Journal of Family Research, 2023
*Title: 06_JFR_Preparation_NRW80+
*Author: Stefan Mauritz
*Data set: NRW80+ panel data (ZA7893_v1-0-0), doi: 10.4232/1.13985
********************************************************************************
********************************************************************************

clear all
capture log close
version 17.0
set more off

*Directories
global inpath 	//	directory of original data
global outpath 	//  working directory
cd $inpath		


********************************************************************************
******************************DATA PREPARATION**********************************
********************************************************************************

use ZA7893_v1-0-0, clear

label def aging1 0 "not at all" 1 "a little bit" 2 "moderate" 3 "strong" 4 "very strong" // positively formulated perceptions
label def aging2 0 "very strong" 1 "strong" 2 "moderate" 3 "a little bit" 4 "not at all" // negatively formulated perceptions
label def aging3 0 "negative PA" 4 "positive PA"
label def family 1 "married" 2 "divorced/separated" 3 "widowed" 4 "never married"
label def wid 0 "married" 1 "widowed"
label def dich 0 "no" 1 "yes"
label def sex 0 "men" 1 "women"
label def educ 0 "low" 1 "medium" 2 "high"
label def nsize 9 "9 or more"


****************************DEPENDENT VARIABLES*********************************

*Freedom
tab alterl9_W1
gen freedom_W1=alterl9_W1
label var freedom_W1 "Freedom W1"
recode freedom_W1 (-3=.) (-2=.) (-1=.) (1=0) (2=1) (3=2) (4=3) (5=4)
label val freedom_W1 aging1
tab freedom_W1
tab alterl9_W2
gen freedom_W2=alterl9_W2
recode freedom_W2 (-3=.) (-2=.) (-1=.) (1=0) (2=1) (3=2) (4=3) (5=4)
label var freedom_W2 "Freedom W2"
label val freedom_W2 aging1
tab freedom_W2

*Needs
tab alterl5_W1
gen needs_W1=alterl5_W1
recode needs_W1 (-3=.) (-2=.) (-1=.) (1=0) (2=1) (3=2) (4=3) (5=4)
label var needs_W1 "Needs W1"
label val needs_W1 aging1
tab needs_W1
tab alterl5_W2
gen needs_W2=alterl5_W2
recode needs_W2 (-3=.) (-2=.) (-1=.) (1=0) (2=1) (3=2) (4=3) (5=4)
label var needs_W2 "Needs W2"
label val needs_W2 aging1
tab needs_W2

*Adaption
tab alterl6_W1
gen adaption_W1=alterl6_W1
recode adaption_W1 (-3=.) (-2=.) (-1=.) (1=4) (2=3) (3=2) (4=1) (5=0)
label var adaption_W1 "Adaption W1"
label val adaption_W1 aging2
tab adaption_W1
tab alterl6_W2
gen adaption_W2=alterl6_W2
recode adaption_W2 (-3=.) (-2=.) (-1=.) (1=4) (2=3) (3=2) (4=1) (5=0)
label var adaption_W2 "Adaption W2"
label val adaption_W2 aging2
tab adaption_W2

*Cognitive capacity
tab alterl3_W1
gen cognitive_W1=alterl3_W1
recode cognitive_W1 (-3=.) (-2=.) (-1=.) (1=4) (2=3) (3=2) (4=1) (5=0)
label var cognitive_W1 "Cognitive capacity W1"
label val cognitive_W1 aging2
tab cognitive_W1
tab alterl3_W2
gen cognitive_W2=alterl3_W2
recode cognitive_W2 (-3=.) (-2=.) (-1=.) (1=4) (2=3) (3=2) (4=1) (5=0)
label var cognitive_W2 "Cognitive capacity W2"
label val cognitive_W2 aging2
tab cognitive_W2

*Dependency
tab alterl8_W1
gen dependency_W1=alterl8_W1
recode dependency_W1 (-3=.) (-2=.) (-1=.) (1=4) (2=3) (3=2) (4=1) (5=0)
label var dependency_W1 "Dependency W1"
label val dependency_W1 aging2
tab dependency_W1
tab alterl8_W2
gen dependency_W2=alterl8_W2
recode dependency_W2 (-3=.) (-2=.) (-1=.) (1=4) (2=3) (3=2) (4=1) (5=0)
label var dependency_W2 "Dependency W2"
label val dependency_W2 aging2
tab dependency_W2

*Vitality
tab alterl7_W1
gen vitality_W1=alterl7_W1
recode vitality_W1 (-3=.) (-2=.) (-1=.) (1=4) (2=3) (3=2) (4=1) (5=0)
label var vitality_W1 "Vitality W1"
label val vitality_W1 aging2
tab vitality_W1
tab alterl7_W2
gen vitality_W2=alterl7_W2
recode vitality_W2 (-3=.) (-2=.) (-1=.) (1=4) (2=3) (3=2) (4=1) (5=0)
label var vitality_W2 "Vitality W2"
label val vitality_W2 aging2
tab vitality_W2

*Serenity
tab alterl4_W1
gen serenity_W1=alterl4_W1
recode serenity_W1 (-3=.) (-2=.) (-1=.) (1=0) (2=1) (3=2) (4=3) (5=4)
label var serenity_W1 "Serenity W1"
label val serenity_W1 aging1
tab serenity_W1
tab alterl4_W2
gen serenity_W2=alterl4_W2
recode serenity_W2 (-3=.) (-2=.) (-1=.) (1=0) (2=1) (3=2) (4=3) (5=4)
label var serenity_W2 "Serenity W2"
label val serenity_W2 aging1
tab serenity_W2

*Index for PA
corr freedom_W1 needs_W1 adaption_W1 cognitive_W1 dependency_W1 vitality_W1 serenity_W1
alpha freedom_W1 needs_W1 adaption_W1 cognitive_W1 dependency_W1 vitality_W1 serenity_W1, item
egen pa_W1=rowmean(freedom_W1 needs_W1 adaption_W1 cognitive_W1 dependency_W1 vitality_W1 serenity_W1)
label var pa_W1 "Perceptions of aging (index) W1"
label val pa_W1 aging3
tab pa_W1
corr freedom_W2 needs_W2 adaption_W2 cognitive_W2 dependency_W2 vitality_W2 serenity_W2
alpha freedom_W2 needs_W2 adaption_W2 cognitive_W2 dependency_W2 vitality_W2 serenity_W2, item
egen pa_W2=rowmean(freedom_W2 needs_W2 adaption_W2 cognitive_W2 dependency_W2 vitality_W2 serenity_W2)
label var pa_W2 "Perceptions of aging (index) W2"
label val pa_W2 aging3
tab pa_W2


***************************INDEPENDENT VARIABLES********************************

*Marital status
tab famst1_W1
gen marital_W1=famst1_W1
recode marital_W1 (-3=.) (-2=.) (-1=.) (1=1) (2=2) (3=2) (4=3) (5=4) (6=1) (7=2) (8=2) (9=3)
label var marital_W1 "Marital status W1"
label val marital_W1 family
tab marital_W1
tab famst1_W2
gen marital_W2=famst1_W2
recode marital_W2 (-3=.) (-2=.) (-1=.) (1=1) (2=2) (3=2) (4=3) (5=4) (6=1) (7=2) (8=2) (9=3)
label var marital_W2 "Marital status W2"
label val marital_W2 family
tab marital_W2

*Widowhood
gen widowed_W1=.
replace widowed_W1=1 if marital_W1==3
replace widowed_W1=0 if marital_W1==1
label var widowed_W1 "Widowhood W1"
label val widowed_W1 wid
tab widowed_W1
gen widowed_W2=.
replace widowed_W2=1 if marital_W2==3
replace widowed_W2=0 if marital_W2==1
label var widowed_W2 "Widowhood W2"
label val widowed_W2 wid
tab widowed_W2

*Gender (time-constant)
tab geschlecht_W1
tab geschlecht_W2
tab geschlecht_W1 geschlecht_W2
gen gender_W=geschlecht_W1
recode gender_W (1=0) (2=1)
label var gender_W "Gender"
label val gender_W sex
tab gender_W

*Interaction term: gender & widowhood
tab widowed_W1
tab gender_W
tab widowed_W1 gender_W
gen genderwid_W1=widowed_W1*gender_W
label var genderwid_W1 "Interaction gender/widowhood W1"
label val genderwid_W1 dich
tab genderwid_W1
tab widowed_W2
tab gender_W
tab widowed_W2 gender_W
gen genderwid_W2=widowed_W2*gender_W
label var genderwid_W2 "Interaction gender/widowhood W2"
label val genderwid_W2 dich
tab genderwid_W2


*****************************CONTROL VARIABLES**********************************

***Covariates
*Educational attainment (time-constant)
tab iscedDEAS_korr5_W1
tab iscedDEAS_korr5_W2
tab iscedDEAS_korr5_W1 iscedDEAS_korr5_W2
gen education_W=iscedDEAS_korr5_W1
recode education_W (1=0) (2=1) (3=2)
label var education_W "Educational attainment"
label val education_W educ
tab education_W

*Migration experience (time-constant)
tab herkun1_W1
tab herkun1_W2
tab herkun1_W1 herkun1_W2
gen migrat_W=herkun1_W1
recode migrat_W (-3=.) (-2=.) (-1=.) (1=0) (2=1) (3=1)
label var migrat_W "Migration experience"
label val migrat_W dich
tab migrat_W

*Age
tab alter_int_W1
gen age_W1=alter_int_W1
label var age_W1 "Age W1"
tab age_W1
tab alter_int_W2
gen age_W2=alter_int_W2
label var age_W2 "Age W2"
tab age_W2

*Physical health
tab multmor_m_W1
recode multmor_m_W1 (-5=.) (-4=.) (-3=.) (-2=.) (-1=.)
gen health_W1=multmor_m_W1*19
label var health_W1 "Physical health W1"
tab health_W1
tab multmor_m19_W2
recode multmor_m19_W2 (-5=.) (-4=.) (-3=.) (-2=.) (-1=.)
gen health_W2=multmor_m19_W2*19
label var health_W2 "Physical health W2"
tab health_W2

*Grandparenthood
tab enkel1_W1
gen grandparents_W1=enkel1_W1
recode grandparents_W1 (-3=0) (-2=.) (-1=.)
replace grandparents_W1=1 if enkel1_W1>=1
label var grandparents_W1 "Grandparenthood W1"
label val grandparents_W1 dich
tab grandparents_W1
tab enkel1_W2
gen grandparents_W2=enkel1_W2
recode grandparents_W2 (-3=0) (-2=.) (-1=.)
replace grandparents_W2=1 if enkel1_W2>=1
label var grandparents_W2 "Grandparenthood W2"
label val grandparents_W2 dich
tab grandparents_W2

*Network size
tab soznetz_W1
gen network_W1=soznetz_W1
recode network_W1 (-3=.) (-2=.) (-1=.)
replace network_W1=9 if network_W1>=9 & network_W1!=.
label var network_W1 "Network size W1"
label val network_W1 nsize
tab network_W1
tab soznetz_W2
gen network_W2=soznetz_W2
recode network_W2 (-3=.) (-2=.) (-1=.)
replace network_W2=9 if network_W2>=9 & network_W2!=.
label var network_W2 "Network size W2"
label val network_W2 nsize
tab network_W2

***Variables for sample description
*Constantly married (married in both waves)
gen conmarried_W=0
replace conmarried_W=. if marital_W1==. | marital_W2==.
replace conmarried_W=1 if marital_W1==1 & marital_W2==1
label var conmarried_W "Constantly married"
label val conmarried_W dich
tab conmarried_W

*Constantly widowed (widowed in both waves)
gen conwidowed_W=0
replace conwidowed_W=. if marital_W1==. | marital_W2==.
replace conwidowed_W=1 if marital_W1==3 & marital_W2==3
label var conwidowed_W "Constantly widowed"
label val conwidowed_W dich
tab conwidowed_W

*Recently widowed (widowhood between wave 1 and wave 2)
gen recwidowed_W=.
replace recwidowed_W=0 if widowed_W1==widowed_W2
replace recwidowed_W=1 if widowed_W1!=widowed_W2
label var recwidowed_W "Recently widowed (widowhood wave1/wave2)"
label val recwidowed_W dich
tab recwidowed_W

*Age at widowhood
tab famst3_dur_W1
recode famst3_dur_W1 (-3=.) (-2=.) (-1=.)
gen widowage_W=age_W1-famst3_dur_W1
label var widowage_W "Age at widowhood"
tab widowage_W


****************************SAMPLE & VARIABLES**********************************

*Sample
tab marital_W1
tab marital_W2
tab widowed_W1
tab widowed_W2
drop if widowed_W1==. // exclude respondents who are divorced/separated or never married
drop if widowed_W2==.
drop if brfzp1_W1==3 // exclude respondents who are not retired

*Variables
keep ID freedom_W1 freedom_W2 needs_W1 needs_W2 adaption_W1 adaption_W2 cognitive_W1 cognitive_W2 dependency_W1 dependency_W2 vitality_W1 vitality_W2 serenity_W1 serenity_W2 pa_W1 pa_W2 widowed_W1 widowed_W2 gender_W genderwid_W1 genderwid_W2 education_W migrat_W age_W1 age_W2 health_W1 health_W2 grandparents_W1 grandparents_W2 network_W1 network_W2 conmarried_W conwidowed_W recwidowed_W widowage_W

save preparation_NRW80, replace
exit
