********************************************************************************
********************************************************************************
*Do partnership transitions affect the individual perception of aging in later life? Findings from the German Ageing Survey and the NRW80+ study
*Journal of Family Research, 2023
*Title: 08_JFR_Descriptive_Analysis_Baseline_NRW80
*Author: Stefan Mauritz
*Data set: NRW80+ (wave 1, ZA7558_v2-0-0), doi: 10.4232/1.13978
********************************************************************************
********************************************************************************

clear all
capture log close
version 17.0
set more off

*Directories
global inpath 	//	directory of original data
global outpath 	//  working directory
cd $inpath	


********************************************************************************
******************************DATA PREPARATION**********************************
********************************************************************************

use ZA7558_v2-0-0, clear

label def aging1 0 "not at all" 1 "a little bit" 2 "moderate" 3 "strong" 4 "very strong" // positively formulated perceptions
label def aging2 0 "very strong" 1 "strong" 2 "moderate" 3 "a little bit" 4 "not at all" // negatively formulated perceptions
label def aging3 0 "negative PA" 4 "positive PA"
label def family 1 "married" 2 "divorced/separated" 3 "widowed" 4 "never married"
label def dich 0 "no" 1 "yes"
label def sex 0 "men" 1 "women"
label def educ 0 "low" 1 "medium" 2 "high"
label def nsize 9 "9 or more"

*Freedom
tab alterl9
gen freedom=alterl9
label var freedom "Freedom"
recode freedom (-3=.) (-2=.) (-1=.) (1=0) (2=1) (3=2) (4=3) (5=4)
label val freedom aging1
tab freedom

*Needs
tab alterl5
gen needs=alterl5
recode needs (-3=.) (-2=.) (-1=.) (1=0) (2=1) (3=2) (4=3) (5=4)
label var needs "Needs"
label val needs aging1
tab needs

*Adaption
tab alterl6
gen adaption=alterl6
recode adaption (-3=.) (-2=.) (-1=.) (1=4) (2=3) (3=2) (4=1) (5=0)
label var adaption "Adaption"
label val adaption aging2
tab adaption

*Cognitive capacity
tab alterl3
gen cognitive=alterl3
recode cognitive (-3=.) (-2=.) (-1=.) (1=4) (2=3) (3=2) (4=1) (5=0)
label var cognitive "Cognitive capacity"
label val cognitive aging2
tab cognitive

*Dependency
tab alterl8
gen dependency=alterl8
recode dependency (-3=.) (-2=.) (-1=.) (1=4) (2=3) (3=2) (4=1) (5=0)
label var dependency "Dependency"
label val dependency aging2
tab dependency

*Vitality
tab alterl7
gen vitality=alterl7
recode vitality (-3=.) (-2=.) (-1=.) (1=4) (2=3) (3=2) (4=1) (5=0)
label var vitality "Vitality"
label val vitality aging2
tab vitality

*Serenity
tab alterl4
gen serenity=alterl4
recode serenity (-3=.) (-2=.) (-1=.) (1=0) (2=1) (3=2) (4=3) (5=4)
label var serenity "Serenity"
label val serenity aging1
tab serenity

*Index for PA
corr freedom needs adaption cognitive dependency vitality serenity
alpha freedom needs adaption cognitive dependency vitality serenity, item
egen pa=rowmean(freedom needs adaption cognitive dependency vitality serenity)
label var pa "Perceptions of aging (index)"
label val pa aging3
tab pa

*Marital status
tab famst1
gen marital=famst1
recode marital (-3=.) (-2=.) (-1=.) (1=1) (2=2) (3=2) (4=3) (5=4) (6=1) (7=2) (8=2) (9=3)
label var marital "Marital status"
label val marital family
tab marital

*Gender
tab geschlecht
gen gender=geschlecht
recode gender (1=0) (2=1)
label var gender "Gender"
label val gender sex
tab gender

*Educational attainment
tab iscedDEAS
gen education=iscedDEAS
recode education (1=0) (2=1) (3=2)
label var education "Educational attainment"
label val education educ
tab education

*Migration experience
tab herkun1
gen migrat=herkun1
recode migrat (-3=.) (-2=.) (-1=.) (1=0) (2=1) (3=1)
label var migrat "Migration experience"
label val migrat dich
tab migrat

*Age
tab alter_int
gen age=alter_int
label var age "Age"
tab age

*Physical health
tab multmor_m
recode multmor_m (-5=.) (-4=.) (-3=.) (-2=.) (-1=.)
gen health=multmor_m*19
label var health "Physical health"
tab health

*Grandparenthood
tab enkel1
gen grandparents=enkel1
recode grandparents (-3=0) (-2=.) (-1=.)
replace grandparents=1 if enkel1>=1
label var grandparents "Grandparenthood"
label val grandparents dich
tab grandparents

*Network size
tab soznetz
gen network=soznetz
recode network (-3=.) (-2=.) (-1=.)
replace network=9 if network>=9 & network!=.
label var network "Network size"
label val network nsize
tab network

*Age at widowhood
tab famst3_dur
recode famst3_dur (-3=.) (-2=.) (-1=.)
gen widowage=age-famst3_dur
label var widowage "Age at widowhood"
tab widowage

keep ID freedom needs adaption cognitive dependency vitality serenity pa marital gender education migrat age health grandparents network widowage
save preparation_NRW80_baseline, replace


********************************************************************************
******************************SAMPLE DESCRIPTION********************************
***************the following code was used to create Table A.1b*****************
********************************************************************************

use preparation_NRW80_baseline, clear

sum ID freedom needs adaption cognitive dependency vitality serenity pa gender migrat age health grandparents network widowage
tab marital
tab education

exit
